*** Settings ***
Documentation     Basic Tests for some special pages
Resource          ../Keywords/django.resource
Suite Setup       Solawi-Suite Inner Setup
Suite Teardown    Solawi-Suite Inner Teardown

*** Keywords ***
Find Link To Special Page
    [Arguments]    ${special_page_url}
    Get Element Count    css=a[href="${special_page_url}"]    >    0

Check Pages For Special Page "${page_url}"
    [Arguments]    @{pages}
    FOR    ${page}    IN    @{pages}
        Open Page    ${page}
        Find Link To Special Page    ${page_url}
    END
    
Can Successfully Open "${url}"
    Open Page    /
    &{res} =           HTTP             ${url}
    Should Be Equal As Integers         ${res.status}    200

*** Test Cases ***
Redirect To Welcome Page - User Site
    [Documentation]    Tests the redirect from the base URL to the welcome page
    Open Page    /
    Get Url    $=    /ui/welcome

Check Imprint Page
    [Documentation]    Is there an Imprint Page containing "Impressum" and "Datenschutz"
    Open Page    /ui/impressum
    Get Element By Role   heading    name=Impressum
    Get Element By Role   heading    name=Datenschutz
    
Check Contact Page
    [Documentation]    Is there a Contact Page containing contact information
    Open Page    /ui/contact
    Get Element By Role    heading    name=Kontakt    exact=True
    Get Element By Role    heading    name=Kontaktmöglichkeiten    exact=True
    Get Element Count    css=a[href="mailto:solawi-suite@solawi.me"]    >    0

Has Contact Page Link
    [Documentation]    Tests the reachability of the contact page from a bunch of pages
    Check Pages For Special Page "/ui/contact"    /ui/welcome    /ui/contact    /ui/impressum    /handbook/    /users/auth/login

Has Imprint Page Link
    [Documentation]    Tests the reachability of the imprint/data protection page from a bunch of pages
    Check Pages For Special Page "/ui/impressum"    /ui/welcome    /ui/contact    /ui/impressum    /handbook/    /users/auth/login

Has About Page Link
    [Documentation]    Tests the reachability of the about page from a bunch of pages
    Check Pages For Special Page "/ui/about"    /ui/welcome    /ui/contact    /ui/impressum    /users/auth/login

Has favicon.ico
    Can Successfully Open "/favicon.ico"

Has favicon.png
    Can Successfully Open "/favicon.png"

Has robots.txt
    Can Successfully Open "/robots.txt"

Has ads.txt
    Can Successfully Open "/ads.txt"

Has .well-known/security.txt
    Can Successfully Open "/.well-known/security.txt"

Has ui/matomo.js
    Can Successfully Open "/ui/matomo.js"
