import django.db.models.deletion
import solawi_apps.db_lib.dbid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Ahg',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('owner_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Beisitzer')),
            ],
            options={
                'verbose_name': 'Abholgemeinschaft',
                'verbose_name_plural': 'Abholgemeinschaften',
                'default_permissions': (),
                'unique_together': {('owner_fk', 'name')},
            },
        ),
        migrations.CreateModel(
            name='HarvestYear',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('year', models.CharField(max_length=255, verbose_name='Jahr')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('ahg_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.ahg', verbose_name='Abholgemeinschaft')),
            ],
            options={
                'verbose_name': 'Erntejahr',
                'verbose_name_plural': 'Erntejahre',
                'default_permissions': (),
                'unique_together': {('year', 'ahg_fk')},
            },
        ),
        migrations.CreateModel(
            name='Date',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('date', models.DateField(verbose_name='Datum')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('needs_pickup', models.BooleanField(default=True, verbose_name='Benötigt Abholung')),
                ('harvest_year_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.harvestyear', verbose_name='Erntejahr')),
            ],
            options={
                'verbose_name': 'Datum',
                'verbose_name_plural': 'Daten',
                'default_permissions': (),
                'unique_together': {('harvest_year_fk', 'date')},
            },
        ),
        migrations.CreateModel(
            name='Member',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('email', models.EmailField(default=None, max_length=254, null=True, verbose_name='E-Mail')),
                ('requires_team', models.BooleanField(default=False, verbose_name='Benötigt Team')),
                ('shares', models.DecimalField(blank=True, decimal_places=2, default=1.0, max_digits=3, null=True, verbose_name='Anteile')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('ahg_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.ahg', verbose_name='Abholgemeinschaft')),
            ],
            options={
                'verbose_name': 'Mitglied',
                'verbose_name_plural': 'Mitglieder',
                'default_permissions': (),
                'unique_together': {('ahg_fk', 'name')},
            },
        ),
        migrations.CreateModel(
            name='Team',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('name', models.CharField(max_length=255, verbose_name='Team-Name')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('ahg_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.ahg', verbose_name='Abholgemeinschaft')),
            ],
            options={
                'verbose_name': 'Abhol-Team',
                'verbose_name_plural': 'Abhol-Teams',
                'default_permissions': (),
                'unique_together': {('ahg_fk', 'name')},
            },
        ),
        migrations.CreateModel(
            name='PlanMemberLink',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('date_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.date', verbose_name='Datum')),
                ('member_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.member', verbose_name='Mitglied')),
            ],
            options={
                'verbose_name': 'Einplanung Mitglied',
                'verbose_name_plural': 'Einplanungen Mitglied',
                'default_permissions': (),
                'unique_together': {('date_fk', 'member_fk')},
            },
        ),
        migrations.CreateModel(
            name='PlanTeamLink',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('date_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.date', verbose_name='Datum')),
                ('team_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.team', verbose_name='Team')),
            ],
            options={
                'verbose_name': 'Einplanung Team',
                'verbose_name_plural': 'Einplanungen Team',
                'default_permissions': (),
                'unique_together': {('date_fk', 'team_fk')},
            },
        ),
        migrations.CreateModel(
            name='TeamMember',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('note', models.TextField(blank=True, default=None, max_length=100000, null=True, verbose_name='Notiz')),
                ('member_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.member', verbose_name='Mitglied')),
                ('team_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ahg.team', verbose_name='Abhol-Team')),
            ],
            options={
                'verbose_name': 'Team-Mitglied',
                'verbose_name_plural': 'Team-Mitglieder',
                'default_permissions': (),
                'unique_together': {('team_fk', 'member_fk')},
            },
        ),
    ]
