from django.contrib import messages
from django.db import models
from django.utils.translation import gettext_lazy as _

from solawi_apps.db_lib.models import NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, \
    LastModifiedMixin


LEVELS = (
    (messages.INFO, "info"),
    (messages.WARNING, "warning"),
    (messages.ERROR, "error"),
    (messages.SUCCESS, "success"),
)


class PublicAnnouncement(
    NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, LastModifiedMixin, models.Model
):

    class Meta:
        verbose_name = _("Öffentliche Ankündigung")
        verbose_name_plural = _("Öffentliche Ankündigungen")

    level = models.PositiveSmallIntegerField(
        verbose_name=_("Level"), choices=LEVELS, null=False, blank=False, default=messages.INFO,
    )
    content = models.TextField(verbose_name=_("Inhalt"), null=False, blank=False, max_length=100_000)
    link = models.TextField(verbose_name=_("Link"), null=True, blank=True, max_length=1_000)
    link_title = models.TextField(verbose_name=_("Link-Titel"), null=True, blank=True, max_length=10_000)
    dismissible = models.BooleanField(verbose_name=_("Kann geschlossen werden"), null=False, blank=False, default=True)

    def __str__(self):
        return _("Öffentliche Ankündigung %s") % self.id


class MemberAnnouncement(
    NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, LastModifiedMixin, models.Model
):

    class Meta:
        verbose_name = _("Ankündigung für Mitglieder")
        verbose_name_plural = _("Ankündigungen für Mitglieder")

    level = models.PositiveSmallIntegerField(
        verbose_name=_("Level"), choices=LEVELS, null=False, blank=False, default=messages.INFO,
    )
    content = models.TextField(verbose_name=_("Inhalt"), null=False, blank=False, max_length=100_000)
    link = models.TextField(verbose_name=_("Link"), null=True, blank=True, max_length=1_000)
    link_title = models.TextField(verbose_name=_("Link-Titel"), null=True, blank=True, max_length=10_000)
    dismissible = models.BooleanField(verbose_name=_("Kann geschlossen werden"), null=False, blank=False, default=True)

    def __str__(self):
        return _("Mitglieder-Ankündigung %s") % self.id
