from django import template
from django.conf import settings
from django.template import RequestContext
from django.utils.safestring import mark_safe
from django.utils.timezone import now

from solawi_apps.announce.context import CONTEXT_SESSION_KEY
from solawi_apps.announce.models import PublicAnnouncement, MemberAnnouncement

register = template.Library()


@register.inclusion_tag("solawi_apps/announce/tag.html", name="announcements", takes_context=True)
def get_announcement_tag(context: RequestContext) -> dict:
    announcements = []
    t_now = now()
    announcement_orm_classes = [PublicAnnouncement]
    if context.request.user.is_authenticated:
        announcement_orm_classes.append(MemberAnnouncement)
    for Announcement in announcement_orm_classes:
        for a in Announcement.objects.filter(
            enabled=True, active_from__lte=t_now, active_to__gte=t_now,
        ).order_by("created").all():
            announcements.append({
                "level": settings.MESSAGE_TAGS.get(a.level),
                "content": mark_safe(a.content),
                "link": a.link,
                "link_title": a.link_title,
                "dismissible": a.dismissible,
            })
    if (context_announcements := context.request.session.get(CONTEXT_SESSION_KEY, None)) is not None:
        for a in context_announcements:
            url_filter = a[3]
            filtered = False
            if url_filter is not None and len(url_filter) > 0:
                for url in url_filter:
                    if context.request.get_full_path().startswith(url):
                        filtered = True
            if not filtered:
                announcements.append({
                    "level": settings.MESSAGE_TAGS.get(a[1]),
                    "content": mark_safe(a[2]),
                    "link": None,
                    "link_title": None,
                    "dismissible": True,
                })
        if len(context_announcements) > 0:
            context.request.session[CONTEXT_SESSION_KEY] = []
    return {
        "a_obj_list": announcements,
    }
