from django.contrib import messages
from django.contrib.auth import get_user_model
from django.test import TestCase
from django.urls import reverse

from solawi_apps.announce.models import PublicAnnouncement, MemberAnnouncement


class SessionBasedAnnouncementTest(TestCase):

    def setUp(self):
        PublicAnnouncement.objects.create(
            enabled=True,
            level=messages.INFO,
            content="PUBLIC ANNOUNCEMENT",
        )
        MemberAnnouncement.objects.create(
            enabled=True,
            level=messages.INFO,
            content="MEMBER ANNOUNCEMENT",
        )
        User = get_user_model()
        User.objects.create_user(username='test', password='passwd', is_active=True)

    def test_announcement_playout_for_anonymous_user(self):
        welcome = reverse("solawi_apps.ui:welcome")
        response = self.client.get(welcome)
        self.assertIn(b"PUBLIC ANNOUNCEMENT", response.content)
        self.assertNotIn(b"MEMBER ANNOUNCEMENT", response.content)

    def test_announcement_playout_for_logged_in_user(self):
        welcome = reverse("solawi_apps.ui:welcome")
        self.client.login(username="test", password="passwd")
        response = self.client.get(welcome)
        self.assertIn(b"PUBLIC ANNOUNCEMENT", response.content)
        self.assertIn(b"MEMBER ANNOUNCEMENT", response.content)
