from django.contrib.auth import get_user_model
from django.db import migrations


def add_passkey_permission_to_existing_users(apps, schema_editor):
    User = get_user_model()
    user_ids = [t.id for t in User.objects.all()]
    AccessPermission = apps.get_model('app_permission', 'AccessPermission')
    AccessPermission.objects.bulk_create([
        AccessPermission(
            user_fk_id=t,
            app_name='solawi_apps.passkeys',
            enabled=True,
        ) for t in user_ids
    ], ignore_conflicts=True)


class Migration(migrations.Migration):

    dependencies = [
        ('app_permission', '0003_default_permissions'),
    ]

    operations = [
        migrations.RunPython(add_passkey_permission_to_existing_users),
    ]
