from django.contrib.auth.mixins import AccessMixin
from django.http import HttpRequest
from django.shortcuts import redirect
from django.urls import reverse_lazy
from django.utils.timezone import now

from solawi_apps.app_permission.models import AccessPermission


class AccessPermissionRequiredMixin(AccessMixin):

    app_name = None
    app_access_denied_url = reverse_lazy("solawi_apps.app_permission:permission-denied")

    def get_app_name(self):
        return self.app_name

    def get_app_access_denied_url(self):
        return self.app_access_denied_url

    def dispatch(self, request: HttpRequest, *args, **kwargs):
        if not request.user.is_authenticated:
            return self.handle_no_permission()
        app_name = self.get_app_name()
        if request.user.is_superuser or app_name is None:
            return super().dispatch(request, *args, **kwargs)
        t_now = now()
        if AccessPermission.objects.filter(
            user_fk=request.user,
            enabled=True,
            active_from__lte=t_now,
            active_to__gte=t_now,
            app_name=app_name,
        ).exists():
            return super().dispatch(request, *args, **kwargs)
        return redirect(self.get_app_access_denied_url(), permanent=False)
