from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from solawi_apps.app_permission.integration import get_all_installed_app_labels
from solawi_apps.db_lib.models import NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, \
    LastModifiedMixin


class AccessPermission(
    NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, LastModifiedMixin, models.Model
):

    class Meta:
        verbose_name = _("Zugangsberechtigung")
        verbose_name_plural = _("Zugangsberechtigungen")
        unique_together = (
            ("app_name", "user_fk"),
        )

    app_name = models.CharField(
        verbose_name=_("App Name"), null=False, blank=False, max_length=200, choices=get_all_installed_app_labels
    )
    user_fk = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, null=False, blank=False
    )

    def __str__(self):
        return f"{self.app_name} => {self.user_fk.email}"


class DefaultPermission(
    NanoIdPkMixin, EnabledMixin, ActiveFromMixin, ActiveToMixin, CreatedMixin, LastModifiedMixin, models.Model
):

    class Meta:
        verbose_name = _("Standard Zugangsberechtigung")
        verbose_name_plural = _("Standard Zugangsberechtigungen")

    app_name = models.CharField(
        verbose_name=_("App Name"),
        null=False,
        blank=False,
        max_length=200,
        choices=get_all_installed_app_labels,
        unique=True,
    )

    def __str__(self):
        return self.app_name
