from urllib.parse import quote

from django.conf import settings
from django.contrib.auth.models import AnonymousUser
from django.core.exceptions import PermissionDenied
from django.test import SimpleTestCase, RequestFactory

from solawi_apps.app_permission.mixin import AccessPermissionRequiredMixin


class AccessMixinInUseWithRaiseTest(SimpleTestCase):

    @classmethod
    def setUpClass(cls):
        class ConfiguredAccessPermissionRequiredMixin(AccessPermissionRequiredMixin):
            app_name = 'test'
            raise_exception = True

        cls.mixin = ConfiguredAccessPermissionRequiredMixin()

    def setUp(self):
        self.factory = RequestFactory()
        self.request = self.factory.get("/")
        setattr(self.mixin, 'request', self.request)

    def tearDown(self):
        delattr(self.mixin, 'request')

    def test_get_app_name(self):
        self.assertEqual(self.mixin.get_app_name(), 'test')

    def test_anon_request(self):
        self.request.user = AnonymousUser()
        with self.assertRaises(PermissionDenied):
            self.mixin.dispatch(self.request)


class AccessMixinInUseWithoutRaiseTest(SimpleTestCase):

    @classmethod
    def setUpClass(cls):
        class ConfiguredAccessPermissionRequiredMixin(AccessPermissionRequiredMixin):
            app_name = 'test'
            raise_exception = False

        cls.mixin = ConfiguredAccessPermissionRequiredMixin()

    def setUp(self):
        self.factory = RequestFactory()
        self.request = self.factory.get("/")
        setattr(self.mixin, 'request', self.request)

    def tearDown(self):
        delattr(self.mixin, 'request')

    def test_get_app_name(self):
        self.assertEqual(self.mixin.get_app_name(), 'test')

    def test_anon_request(self):
        self.request.user = AnonymousUser()
        response = self.mixin.dispatch(self.request)
        self.assertEqual(response.status_code, 302)
        self.assertRedirects(
            response, f"{settings.LOGIN_URL}?next={quote('/')}", fetch_redirect_response=False
        )
