from unittest import skip

from bs4 import BeautifulSoup
from django.test import TestCase
from django.urls import reverse

from solawi_apps.testing.testlib import SeleniumTestCase


class BeamerViewTest(TestCase):

    def test_public_page_available(self):
        result = self.client.get(reverse("solawi_apps.beamer:home"))
        self.assertEqual(result.status_code, 200)
        self.assertContains(result, "Screen Code")
        self.assertContains(result, "[solawi-suite]")

    def test_screen_code(self):
        result = self.client.get(reverse("solawi_apps.beamer:home"))
        self.assertEqual(result.status_code, 200)
        soup = BeautifulSoup(result.content.decode(result.charset), features="html5lib")
        screen_code = soup.css.select("body header b")
        self.assertEqual(len(screen_code), 1)
        screen_code_text = screen_code[0].text
        self.assertRegex(screen_code_text, r"^\d{16}$")


@skip
class SendToBeamerTest(SeleniumTestCase):

    def setUp(self):
        super().setUp()
        self.beamer_page = self.live_server_url + reverse("solawi_apps.beamer:home")

    def test_send_to_beamer(self):
        self.assertTrue(self.beamer_page is not None)

    def test_page(self):
        self.selenium.get(self.beamer_page)
