import django_eventstream
from django.urls import path, include, register_converter

from solawi_apps.beamer.views import BeamerView, ConnectionListView, DeleteConnectionView, ResetConnectionView, \
    SendTestMessageView, QrCode


class BeamerIdConverter:
    regex = "[0-9]{16}"

    def to_python(self, value):
        return str(value)

    def to_url(self, value):
        return str(value)


register_converter(BeamerIdConverter, "beamer_id")


urlpatterns = [
    path("beamer-<beamer_id:obj_id>", include(django_eventstream.urls), {'format-channels': ['beamer-{obj_id}']}),
    path("connections", ConnectionListView.as_view(), name="connections"),
    path("connection", DeleteConnectionView.as_view(), name="connections.del"),
    path("connection/<beamer_id:beamer_id>", SendTestMessageView.as_view(), name="connections.test"),
    path("connection-reset", ResetConnectionView.as_view(), name="connections.reset"),
    path("qr/<str:url_signed>", QrCode.as_view(), name="qr-code"),
    path("", BeamerView.as_view(), name="home"),
]
app_name = 'solawi_apps.beamer'
