from django import forms
from django.core.validators import RegexValidator
from django.forms import PasswordInput
from django.utils.translation import gettext_lazy as _


class SelectEventForm(forms.Form):

    event_pin = forms.CharField(min_length=12, max_length=16, strip=True, required=True, validators=[
        RegexValidator(regex=r"^(\s?\d{3}){4}\s?$", message=_("Diese Ereignis-PIN hat ein ungültiges Format.")),
    ], label=_("Ereignis-PIN"))


class BidForm(forms.Form):

    share = forms.CharField(max_length=32, min_length=1, required=True, strip=True, label=_("Anteils-ID"))
    pin = forms.CharField(min_length=6, max_length=7, required=True, label=_("PIN"), strip=True, validators=[
        RegexValidator(regex=r"^(\d{6})|(\d{3}\s\d{3})$"),
    ], widget=PasswordInput)
    bid = forms.DecimalField(
        min_value=0, max_value=999_999, required=True, decimal_places=2, max_digits=8, label=_("Gebot"),
        help_text=_("Betrag bei monatlicher Zahlweise"),
    )
