from django import forms
from django.utils.translation import gettext_lazy as _

from solawi_apps.bidding.models import TeamMember


class TeamMemberForm(forms.ModelForm):

    class Meta:
        model = TeamMember
        fields = [
            "perm_add_bid",
            "perm_add_prebid",
            "perm_get_report",
            "perm_start_round",
            "perm_end_round",
            "active_from",
            "active_to",
            "enabled",
        ]


class AddTeamMemberForm(TeamMemberForm):

    email = forms.EmailField(
        label=_("E-Mail-Adresse"),
        help_text=_('Benutzer:in muss bereits registriert sein und Zugang zur Applikation "Digitales Gebot" haben.'),
        required=True,
    )


class TransferEventForm(AddTeamMemberForm):

    stay_in_team = forms.BooleanField(label=_("Im Team verbleiben"), initial=False, required=False)


class TeamAddBidForm(forms.Form):

    share = forms.CharField(max_length=32, min_length=1, required=True, strip=True, label=_("Anteils-ID"))
    bid = forms.DecimalField(
        min_value=0, max_value=999_999, required=True, decimal_places=2, max_digits=8, label=_("Gebot"),
        help_text=_("Betrag bei monatlicher Zahlweise"),
    )
