import datetime
import django.db.models.deletion
import solawi_apps.bidding.pin
import solawi_apps.db_lib.dbid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('active_from', models.DateTimeField(default=datetime.datetime(2000, 1, 1, 0, 0, tzinfo=datetime.timezone.utc), verbose_name='Aktiv ab')),
                ('active_to', models.DateTimeField(default=datetime.datetime(2999, 12, 31, 23, 59, 59, 999999, tzinfo=datetime.timezone.utc), verbose_name='Aktiv bis')),
                ('archived', models.BooleanField(default=False, verbose_name='Archiviert')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('date', models.DateField(verbose_name='Datum')),
                ('event_pin', models.CharField(default=solawi_apps.bidding.pin.make_event_pin, max_length=12, unique=True, verbose_name='Event-PIN')),
                ('owner_fk', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to=settings.AUTH_USER_MODEL, verbose_name='Besitzer')),
            ],
            options={
                'verbose_name': 'Ereignis',
                'verbose_name_plural': 'Ereignisse',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='FiscalPlan',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('required_amount', models.DecimalField(decimal_places=2, max_digits=16, verbose_name='Benötigter Betrag')),
                ('currency', models.CharField(default='EUR', max_length=5, verbose_name='Währung')),
                ('minimum_bid_percentage_of_soli_average', models.DecimalField(decimal_places=3, default=0.0, max_digits=10, verbose_name='Minimalgebot in Prozent des mittleren Solidarbeitrags')),
                ('default_bid_percentage_of_soli_average', models.DecimalField(decimal_places=3, default=0.0, max_digits=10, verbose_name='Standardgebot in Prozent des mittleren Solidarbeitrags')),
                ('default_bid_percentage_of_bids_average', models.DecimalField(decimal_places=3, default=0.0, max_digits=10, verbose_name='Standardgebot in Prozent des Durchschnitts aller abgegebenen Gebote')),
                ('display_share_divider_1', models.BooleanField(default=True, verbose_name='Zeige 1/1 Anteil')),
                ('display_share_divider_2', models.BooleanField(default=True, verbose_name='Zeige 1/2 Anteil')),
                ('display_share_divider_3', models.BooleanField(default=False, verbose_name='Zeige 1/3 Anteil')),
                ('display_share_divider_4', models.BooleanField(default=False, verbose_name='Zeige 1/4 Anteil')),
                ('display_share_divider_5', models.BooleanField(default=False, verbose_name='Zeige 1/5 Anteil')),
                ('display_share_divider_6', models.BooleanField(default=False, verbose_name='Zeige 1/6 Anteil')),
                ('display_share_divider_7', models.BooleanField(default=False, verbose_name='Zeige 1/7 Anteil')),
                ('display_share_divider_8', models.BooleanField(default=False, verbose_name='Zeige 1/8 Anteil')),
                ('display_share_divider_9', models.BooleanField(default=False, verbose_name='Zeige 1/9 Anteil')),
                ('display_share_divider_10', models.BooleanField(default=False, verbose_name='Zeige 1/10 Anteil')),
                ('event_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.event', verbose_name='Ereignis')),
            ],
            options={
                'verbose_name': 'Finanzplan',
                'verbose_name_plural': 'Finanzpläne',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Round',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('name', models.CharField(max_length=200, verbose_name='Runden-Name')),
                ('closed', models.BooleanField(default=False, verbose_name='Runde geschlossen')),
                ('result', models.TextField(default=None, max_length=10000000, null=True, verbose_name='Ergebnis')),
                ('fiscal_plan_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.fiscalplan', verbose_name='Finanzplan')),
            ],
            options={
                'verbose_name': 'Gebots-Runde',
                'verbose_name_plural': 'Gebots-Runden',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Share',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('divider', models.PositiveIntegerField(default=1, verbose_name='Teiler')),
                ('share_id', models.CharField(max_length=32, verbose_name='Anteils-ID')),
                ('share_pin', models.CharField(default=solawi_apps.bidding.pin.make_share_pin, max_length=6, verbose_name='Anteils-PIN')),
                ('owner_name', models.CharField(blank=True, default=None, max_length=200, null=True, verbose_name='Anteilseigner')),
                ('owner_email', models.EmailField(blank=True, default=None, max_length=254, null=True, verbose_name='Anteilseigner E-Mail')),
                ('event_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.event', verbose_name='Ereignis')),
            ],
            options={
                'verbose_name': 'Anteil',
                'verbose_name_plural': 'Anteile',
                'default_permissions': (),
                'unique_together': {('event_fk', 'share_id')},
            },
        ),
        migrations.CreateModel(
            name='PreBid',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('from_round', models.PositiveIntegerField(default=1, verbose_name='Gültig ab Runde')),
                ('fixed_value', models.DecimalField(decimal_places=2, default=0.0, max_digits=16, verbose_name='Fester Gebotsbetrag')),
                ('percentage_of_average_soli', models.DecimalField(decimal_places=3, default=0.0, max_digits=10, verbose_name='Prozentsatz vom mittleren Solidarbeitrag')),
                ('percentage_of_average_bid', models.DecimalField(decimal_places=3, default=0.0, max_digits=10, verbose_name='Prozentsatz vom Mittelwert aller abgegebenen Gebote')),
                ('share_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.share', verbose_name='Anteil')),
            ],
            options={
                'verbose_name': 'Vorab-Gebot',
                'verbose_name_plural': 'Vorab-Gebote',
                'default_permissions': (),
                'unique_together': {('share_fk', 'from_round')},
            },
        ),
        migrations.CreateModel(
            name='Bid',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('value', models.DecimalField(decimal_places=2, max_digits=16, verbose_name='Wert')),
                ('origin', models.TextField(max_length=100000, verbose_name='Gebotsherkunft')),
                ('round_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.round', verbose_name='Runde')),
                ('share_fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bidding.share', verbose_name='Anteil')),
            ],
            options={
                'verbose_name': 'Gebot',
                'verbose_name_plural': 'Gebote',
                'default_permissions': (),
                'unique_together': {('round_fk', 'share_fk')},
            },
        ),
    ]
