from decimal import Decimal
from typing import Union

from django import template
from django.utils.formats import localize

from solawi_apps.bidding.models import Event, FiscalPlan

register = template.Library()


@register.inclusion_tag("solawi_apps/bidding/fiscal_plan/event.tag.html", name="fiscal_plan")
def get_latest_fiscal_plan(event: Event):
    return {
        "plan": FiscalPlan.objects.filter(event_fk=event).order_by("-created").first(),
    }


@register.simple_tag(name="share_dividers")
def get_share_dividers(plan: FiscalPlan) -> list:
    dividers = []
    for d in range(10):
        divider = d + 1
        key = f"display_share_divider_{divider:d}"
        if (obj := getattr(plan, key, None)) is not None:
            if obj:
                dividers.append({
                    "divider": divider,
                })
    return dividers


@register.filter("amount_format")
def get_amount_format(amount: Union[int, float, Decimal], decimal_places: int = 2) -> str:
    f_str = "{:,.%df}" % decimal_places
    value = (f_str.format(float(amount))).replace(".", "#").translate(str.maketrans({
        "#": ",",
        ",": ".",
    }))
    return value
