from json import loads

from django import template

from solawi_apps.bidding.models import Event, Round
from solawi_apps.bidding.object_model import RoundResult
from solawi_apps.bidding.round import can_start_round, can_stop_round

register = template.Library()


@register.inclusion_tag("solawi_apps/bidding/rounds/event.tag.html", name="rounds_summary")
def get_rounds_summary(event: Event):
    context = {
        "event": event,
        "rounds": [{
            "obj": r,
            "res": RoundResult(**loads(r.result))
        } for r in Round.objects.filter(
            fiscal_plan_fk__event_fk=event, closed=True,
        ).select_related("fiscal_plan_fk").order_by("created").all()],
    }
    return context


@register.simple_tag(name="round_can_be_started")
def round_can_be_started(event: Event):
    return can_start_round(event)


@register.simple_tag(name="round_can_be_stopped")
def round_can_be_stopped(event: Event):
    return can_stop_round(event)
