from json import loads
from typing import Dict

from django import template
from django.utils.timezone import now

from solawi_apps.bidding.models import TeamMember, Round
from solawi_apps.bidding.object_model import RoundResult
from solawi_apps.bidding.round import team_can_start_round, team_can_stop_round, can_stop_round, can_start_round

register = template.Library()


@register.inclusion_tag("solawi_apps/bidding/team/tags/bids.html", name="team_bids")
def get_bids_tag(tm: TeamMember) -> Dict:
    if tm.perm_add_bid or tm.perm_add_prebid:
        return {
            "team_permission": True,
            "team_member": tm,
            "add_bid": tm.perm_add_bid,
            "add_bid_enabled": can_stop_round(tm.event_fk),
            "add_prebid": tm.perm_add_prebid,
            "add_prebid_enabled": can_start_round(tm.event_fk),
        }
    return {
        "team_permission": False,
    }


@register.inclusion_tag("solawi_apps/bidding/team/tags/rounds.html", name="team_rounds")
def get_rounds_tag(tm: TeamMember) -> Dict:
    if tm.perm_start_round or tm.perm_end_round:
        return {
            "team_permission": True,
            "team_member": tm,
            "start_round_perm": tm.perm_start_round,
            "start_round_enabled": team_can_start_round(tm),
            "end_round_perm": tm.perm_end_round,
            "end_round_enabled": team_can_stop_round(tm),
        }
    return {
        "team_permission": False,
    }


@register.inclusion_tag("solawi_apps/bidding/team/tags/results.html", name="team_results")
def get_results_tag(tm: TeamMember) -> Dict:
    if not tm.perm_get_report:
        return {
            "team_permission": False,
        }
    t_now = now()
    result_set = Round.objects.filter(
        fiscal_plan_fk__event_fk=tm.event_fk,
        closed=True,
        result__isnull=False,
        fiscal_plan_fk__event_fk__enabled=True,
        fiscal_plan_fk__event_fk__archived=False,
        fiscal_plan_fk__event_fk__active_from__lte=t_now,
        fiscal_plan_fk__event_fk__active_to__gte=t_now,
    ).select_related("fiscal_plan_fk").order_by("created").all()
    return {
        "rounds": [{"obj": r, "res": RoundResult(**loads(r.result))} for r in result_set],
        "team_member": tm,
        "team_permission": True,
        "get_report": tm.perm_get_report,
    }
