from django.urls import path, register_converter

from solawi_apps.bidding.views.archive import EventArchiveListView, ArchivedEventView, ArchivedEventDeleteView, \
    ArchivedEventRoundResultView, ArchivedRoundResultsPdfPageView
from solawi_apps.bidding.views.beamer import ShowEventView, ShowResultView, ShowTeamEventView, ShowTeamResultView
from solawi_apps.bidding.views.events import BiddingEventsView, NewBiddingEventView, ManageEventView, EditEventView, \
    DeleteEventView, ArchiveEventView, RenewEventPinView, AccessLinksView, AccessLinkQrCodeView, TeamMemberView, \
    AddTeamMemberView, EditTeamMemberView, DeleteTeamMemberView, TransferEventView
from solawi_apps.bidding.views.fiscal_plan import AddFiscalPlanView
from solawi_apps.bidding.views.prebids import PrebidListView, AddPreBidView, EditPreBidView, DeletePreBitView
from solawi_apps.bidding.views.rounds import StartRoundView, StopRoundView, RoundResultView, RoundResultPdfView, \
    RoundResultsPdfPageView
from solawi_apps.bidding.views.shares import ShareListView, AddShareView, EditShareView, DeleteShareView, \
    ImportSharesView, ShareSheetView, ShareSheetPdfView
from solawi_apps.bidding.views.team import TeamBiddingEventsView, TeamBiddingEventView, TeamStartRoundView, \
    TeamEndRoundView, TeamRoundResultView, TeamRoundResultPdfView, TeamRoundResultsPdfPageView, TeamPreBidView, \
    TeamAddBidView, TeamEditPreBidView, TeamDeletePreBidView, TeamAddPreBidView
from solawi_apps.bidding.views.user import AccessByPinView, AccessByLinkView, EventView, LeaveEventView
from solawi_apps.db_lib.dbid import NanoIdConverter


register_converter(NanoIdConverter, "nanoid")


urlpatterns = [
    path("events", BiddingEventsView.as_view(), name="events"),
    path("archive", EventArchiveListView.as_view(), name="archive"),
    path("archive/<nanoid:pk>", ArchivedEventView.as_view(), name="archive.event"),
    path("archive/<nanoid:pk>/delete", ArchivedEventDeleteView.as_view(), name="archive.event.delete"),
    path("archive/<nanoid:event_pk>/<nanoid:pk>", ArchivedEventRoundResultView.as_view(), name="archive.event.result"),
    path(
        "archive/<nanoid:event_pk>/<nanoid:pk>/result",
        ArchivedRoundResultsPdfPageView.as_view(),
        name="archive.event.result.page",
    ),
    path("team/events", TeamBiddingEventsView.as_view(), name="team.events"),
    path("team/event/<nanoid:event_pk>/<nanoid:pk>", TeamBiddingEventView.as_view(), name="team.event"),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/round/start",
        TeamStartRoundView.as_view(),
        name="team.event.round.start",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/round/stop",
        TeamEndRoundView.as_view(),
        name="team.event.round.end",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/round/<nanoid:pk>",
        TeamRoundResultView.as_view(),
        name="team.event.round.result",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/round/<nanoid:pk>/beamer",
        ShowTeamResultView.as_view(),
        name="team.event.round.result.beamer",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/round/<nanoid:pk>/result.pdf",
        TeamRoundResultPdfView.as_view(),
        name="team.event.round.result.page.pdf",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/round/<nanoid:pk>/result",
        TeamRoundResultsPdfPageView.as_view(),
        name="team.event.round.result.page",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/beamer",
        ShowTeamEventView.as_view(),
        name="team.event.beamer",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/pre-bids",
        TeamPreBidView.as_view(),
        name="team.event.pre-bids",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/pre-bid",
        TeamAddPreBidView.as_view(),
        name="team.event.pre-bids.add",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/pre-bid/<nanoid:pk>",
        TeamEditPreBidView.as_view(),
        name="team.event.pre-bids.edit",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:team_member_pk>/pre-bid/<nanoid:pk>/delete",
        TeamDeletePreBidView.as_view(),
        name="team.event.pre-bids.delete",
    ),
    path(
        "team/event/<nanoid:event_pk>/<nanoid:pk>/bid",
        TeamAddBidView.as_view(),
        name="team.event.add-bid",
    ),
    path("event", NewBiddingEventView.as_view(), name="events.new"),
    path("event/<nanoid:pk>", ManageEventView.as_view(), name="events.manage"),
    path("event/<nanoid:pk>/beamer", ShowEventView.as_view(), name="events.manage.beamer"),
    path("event/<nanoid:pk>/access", AccessLinksView.as_view(), name="events.manage.access"),
    path("event/<nanoid:pk>/edit", EditEventView.as_view(), name="events.edit"),
    path("event/<nanoid:pk>/delete", DeleteEventView.as_view(), name="events.delete"),
    path("event/<nanoid:pk>/archive", ArchiveEventView.as_view(), name="events.archive"),
    path("event/<nanoid:pk>/renew-pin", RenewEventPinView.as_view(), name="events.renew-pin"),
    path("event/<nanoid:event_pk>/fiscal-plan", AddFiscalPlanView.as_view(), name="events.fiscal-plan"),
    path("event/<nanoid:event_pk>/shares", ShareListView.as_view(), name="events.shares"),
    path("event/<nanoid:event_pk>/share", AddShareView.as_view(), name="events.shares.new"),
    path("event/<nanoid:event_pk>/share/<nanoid:pk>", EditShareView.as_view(), name="events.shares.edit"),
    path("event/<nanoid:event_pk>/share/<nanoid:pk>/rm", DeleteShareView.as_view(), name="events.shares.delete"),
    path("event/<nanoid:event_pk>/shares/import", ImportSharesView.as_view(), name="events.shares.import"),
    path("event/<nanoid:event_pk>/shares/sheet", ShareSheetView.as_view(), name="events.shares.sheet"),
    path("event/<nanoid:event_pk>/shares/sheet.pdf", ShareSheetPdfView.as_view(), name="events.shares.sheet.pdf"),
    path("event/<nanoid:event_pk>/pre-bids", PrebidListView.as_view(), name="events.pre-bids"),
    path("event/<nanoid:event_pk>/pre-bid", AddPreBidView.as_view(), name="events.pre-bids.new"),
    path("event/<nanoid:event_pk>/pre-bid/<nanoid:pk>", EditPreBidView.as_view(), name="events.pre-bids.edit"),
    path("event/<nanoid:event_pk>/pre-bid/<nanoid:pk>/rm", DeletePreBitView.as_view(), name="events.pre-bids.delete"),
    path("event/<nanoid:event_pk>/round/start", StartRoundView.as_view(), name="events.round.start"),
    path("event/<nanoid:event_pk>/round/stop", StopRoundView.as_view(), name="events.round.stop"),
    path("event/<nanoid:event_pk>/round/<nanoid:pk>", RoundResultView.as_view(), name="events.round.result"),
    path(
        "event/<nanoid:event_pk>/round/<nanoid:pk>/beamer",
        ShowResultView.as_view(),
        name="events.round.result.beamer",
    ),
    path(
        "event/<nanoid:event_pk>/round/<nanoid:pk>/result.pdf",
        RoundResultPdfView.as_view(),
        name="events.round.result.pdf",
    ),
    path(
        "event/<nanoid:event_pk>/round/<nanoid:pk>/pdf",
        RoundResultsPdfPageView.as_view(),
        name="events.round.result.page",
    ),
    path("event/<nanoid:event_pk>/transfer", TransferEventView.as_view(), name="events.transfer"),
    path("event/<nanoid:event_pk>/team", TeamMemberView.as_view(), name="events.team.members"),
    path("event/<nanoid:event_pk>/team/add", AddTeamMemberView.as_view(), name="events.team.members.add"),
    path("event/<nanoid:event_pk>/team/<nanoid:pk>", EditTeamMemberView.as_view(), name="events.team.members.edit"),
    path(
        "event/<nanoid:event_pk>/team/<nanoid:pk>/delete",
        DeleteTeamMemberView.as_view(),
        name="events.team.members.delete",
    ),
    path("go", AccessByPinView.as_view(), name="access.pin"),
    path("go/<str:salt>/<str:access_code>", AccessByLinkView.as_view(), name="access.link"),
    path("shareholder", EventView.as_view(), name="if.event"),
    path("shareholder/leave", LeaveEventView.as_view(), name="if.logout"),
    path("qr-code/<str:salt>/<str:payload>", AccessLinkQrCodeView.as_view(), name="access.qr"),
]
app_name = 'solawi_apps.bidding'
