from solawi_apps.bidding.mixin import LoginRequiredMixin
from django.contrib.messages.views import SuccessMessageMixin
from django.forms.models import model_to_dict
from django.urls import reverse
from django.utils.translation import gettext_lazy as _
from django.views.generic import FormView

from solawi_apps.bidding.forms.fiscal_plan import NewFiscalPlanForm
from solawi_apps.bidding.models import FiscalPlan
from solawi_apps.bidding.round import can_stop_round
from solawi_apps.bidding.views.events import GetEventMixin
from solawi_apps.ui.forms.form import ErrorSensitiveFormViewMixin


class AddFiscalPlanView(LoginRequiredMixin, SuccessMessageMixin, ErrorSensitiveFormViewMixin, GetEventMixin, FormView):

    success_message = _("Finanzplan gespeichert.")
    form_class = NewFiscalPlanForm
    event = None
    template_name = "solawi_apps/bidding/fiscal_plan/form.html"

    def get_success_url(self):
        return reverse("solawi_apps.bidding:events.manage", kwargs={
            "pk": self.kwargs.get("event_pk"),
        })

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["cancel_url"] = self.get_success_url()
        context["object"] = self.get_event()
        return context

    def get_initial(self):
        existing_fiscal_plan = FiscalPlan.objects.filter(event_fk=self.get_event()).order_by("-created").first()
        if existing_fiscal_plan is not None:
            return model_to_dict(existing_fiscal_plan)
        return {}

    def form_valid(self, form):
        if can_stop_round(self.get_event()):
            form.add_error(None, _("Aktuell läuft eine Gebotsrunde. Der Finanzplan kann nicht angepasst werden."))
            return self.form_invalid(form)
        FiscalPlan.objects.create(event_fk=self.get_event(), **form.cleaned_data)
        return super().form_valid(form)
