from os.path import dirname, join
from json import loads

from django.db import migrations

from solawi_apps.changelog.object_model import ChangelogDataMigration


DATA_FILE = join(dirname(__file__), '0005_changelog_append.json')


def append_changelog(apps, schema_editor):
    Version = apps.get_model("changelog", "Version")
    Item = apps.get_model("changelog", "Item")
    Ticket = apps.get_model("changelog", "Ticket")
    with open(DATA_FILE, "rt", encoding="utf-8") as fd:
        json_data = fd.read()
    todo = ChangelogDataMigration(**loads(json_data))
    for v in todo.versions:
        version = Version.objects.create(
            version_identifier=v.version_identifier,
            release_datetime=v.release_date,
            note_md=v.note,
            version_name=v.version_name,
            enabled=True,
        )
        for i in v.items:
            item = Item.objects.create(
                version_fk=version,
                enhancement_type=i.item_type,
                requires_db_update=i.requires_db_update,
                is_breaking_change=i.is_breaking_change,
                title=i.title,
                note_md=i.note,
                enabled=True,
            )
            for t in i.tickets:
                Ticket.objects.create(
                    item_fk=item,
                    ticket=t.ticket_id,
                    ticket_url=t.ticket_url,
                    enabled=True,
                )


class Migration(migrations.Migration):

    dependencies = [
        ('changelog', '0004_changelog_append'),
    ]

    operations = [
        migrations.RunPython(append_changelog),
    ]
