from django.db import models
from django.utils.translation import gettext_lazy as _

from solawi_apps.changelog.enhancement import ENHANCEMENT_TYPE
from solawi_apps.db_lib.models import NanoIdPkMixin, CreatedMixin, EnabledMixin


class Version(NanoIdPkMixin, CreatedMixin, EnabledMixin, models.Model):

    class Meta:
        verbose_name = _("Changelog-Version")
        verbose_name_plural = _("Changelog-Versionen")
        default_permissions = ()

    version_identifier = models.CharField(
        verbose_name=_("Versionsbezeichnung"), max_length=255, null=False, blank=False, unique=True,
    )
    release_datetime = models.DateTimeField(_("Veröffentlichungszeitpunkt"), null=False, blank=False)
    note_md = models.TextField(verbose_name=_("Notiz (Markdown)"), null=True, blank=False, max_length=1_000_000)
    version_name = models.TextField(verbose_name=_("Versionsname"), null=True, blank=False, max_length=10_000)

    def __str__(self):
        return self.version_identifier


class Item(NanoIdPkMixin, CreatedMixin, EnabledMixin, models.Model):

    class Meta:
        verbose_name = _("Changelog-Eintrag")
        verbose_name_plural = _("Changelog-Einträge")
        default_permissions = ()

    version_fk = models.ForeignKey(
        Version, verbose_name=_("Version"), null=False, blank=False, on_delete=models.RESTRICT,
    )
    enhancement_type = models.CharField(
        _("Typ"), choices=ENHANCEMENT_TYPE, max_length=128, null=False, blank=False,
    )
    requires_db_update = models.BooleanField(_("Benötigt Datenbank-Schema-Aktualisierung"), null=False, blank=False)
    is_breaking_change = models.BooleanField(_("Ist Breaking Change"), null=False, blank=False)
    title = models.TextField(_("Titel"), null=False, blank=False, max_length=10_000)
    note_md = models.TextField(verbose_name=_("Notiz (Markdown)"), null=True, blank=False, max_length=100_000)

    def __str__(self):
        return self.title


class Ticket(NanoIdPkMixin, CreatedMixin, EnabledMixin, models.Model):

    class Meta:
        verbose_name = _("Ticket")
        verbose_name_plural = _("Tickets")
        default_permissions = ()
        unique_together = (
            ("item_fk", "ticket"),
        )

    item_fk = models.ForeignKey(
        Item, verbose_name=_("Changelog-Eintrag"), null=False, blank=False, on_delete=models.CASCADE,
    )
    ticket = models.CharField(verbose_name=_("Ticket"), null=False, blank=False, max_length=128)
    ticket_url = models.URLField(verbose_name=_("Ticket-URL"), null=True, blank=False, max_length=255)

    def __str__(self):
        return self.ticket
