from typing import Dict

from django import template

from solawi_apps.changelog.models import Version, Item, Ticket

register = template.Library()


@register.inclusion_tag("solawi_apps/changelog/packs/version.html", name="render_version")
def render_version(version: Version) -> Dict:
    return {
        "version": version,
        "items": Item.objects.filter(version_fk=version, enabled=True).order_by("created").all()
    }


@register.inclusion_tag("solawi_apps/changelog/packs/item.html", name="render_item")
def render_item(item: Item) -> Dict:
    return {
        "item": item,
        "tickets": Ticket.objects.filter(item_fk=item, enabled=True).order_by("ticket", "created").all()
    }


@register.inclusion_tag("solawi_apps/changelog/packs/ticket.html", name="render_ticket")
def render_ticket(ticket: Ticket) -> Dict:
    return {
        "ticket": ticket,
    }


@register.inclusion_tag("solawi_apps/changelog/packs/_enhancement-type-icon.html", name="enhancement_type_icon")
def render_enhancement_type_icon(enhancement_type: str) -> Dict:
    return {
        "type": enhancement_type,
    }
