from argparse import ArgumentParser

from django.conf import settings
from django.core.management import BaseCommand, CommandError
from django.utils.translation import gettext_lazy as _

from solawi_apps.encrypted_settings.crypt import encrypt_item
from solawi_apps.encrypted_settings.files import PUBLIC_KEY_FILE_NAME_TEMPLATE
from solawi_apps.encrypted_settings.validators import validate_environment_name


class Command(BaseCommand):

    help = _("Verschlüssele ein Element für eine bestimmte Umgebung")

    def add_arguments(self, parser: ArgumentParser):
        parser.add_argument("item", nargs="+", type=str, help=_("Zu verschlüsselndes Element"))
        parser.add_argument("--env", type=str, required=True, help=_("Zielumgebung"))

    def handle(self, *args, **options):
        if (items := options["item"]) is None or len(items) == 0:
            raise CommandError(_("keine Elemente angegeben"))
        if (env := options["env"]) is None or not validate_environment_name(env, raise_on_validation_error=False):
            raise CommandError(_("ungültige Umgebung"))
        public_key_file = settings.PUBLIC_KEY_DIR / (PUBLIC_KEY_FILE_NAME_TEMPLATE % env)
        if not public_key_file.exists() or not public_key_file.is_file():
            raise CommandError(_("keinen Public Key für die angegebene Umgebung gefunden"))
        with open(public_key_file, "rt", encoding="utf-8") as pk_fd:
            public_key = pk_fd.read().strip()
        for item in items:
            self.stdout.write(f"{item} = {encrypt_item(item, public_key)}")
