import os
from unittest import mock

from django.test import SimpleTestCase
from ecies.utils import generate_eth_key

from solawi_apps.encrypted_settings.crypt import encrypt_item, decrypt_item


class RoundtripTest(SimpleTestCase):

    @classmethod
    def setUpClass(cls):
        key = generate_eth_key()
        cls.public_key = key.public_key.to_hex()
        cls.secret_key = key.to_hex()

    def test_roundtrip(self):
        cases = ("", " ", " a ", "abc", "ÄAöÜÖÄß", "💬🏁")
        for case in cases:
            with self.subTest("case '{}'".format(case)):
                encrypted = encrypt_item(case, self.public_key)
                self.assertIsNotNone(encrypted)
                self.assertNotEqual(case, encrypted)
                decrypted = decrypt_item(encrypted, self.secret_key)
                self.assertEqual(case, decrypted)

    def test_roundtrip_transparent(self):
        with mock.patch.dict(os.environ, {"SOLAWI_SUITE_SECRET_KEY": self.secret_key}):
            cases = ("", " ", " a ", "abc", "ÄAöÜÖÄß", "💬🏁")
            for case in cases:
                with self.subTest("case '{}'".format(case)):
                    encrypted = encrypt_item(case)
                    self.assertIsNotNone(encrypted)
                    self.assertNotEqual(case, encrypted)
                    decrypted = decrypt_item(encrypted)
                    self.assertEqual(case, decrypted)


class DecryptionTest(SimpleTestCase):

    @classmethod
    def setUpClass(cls):
        key = generate_eth_key()
        cls.public_key = key.public_key.to_hex()
        cls.secret_key = key.to_hex()

    def test_invalid_secret_key(self):
        encrypted = encrypt_item("test", self.public_key)
        with self.assertRaises(ValueError):
            decrypt_item(encrypted, self.secret_key.replace("1", "2").replace("3", "4").replace("5", "6"))
