from django.core.exceptions import ValidationError
from django.test import SimpleTestCase

from solawi_apps.encrypted_settings.validators import validate_environment_name


class EnvironmentNameValidationTest(SimpleTestCase):

    def test_environment_name_validation(self):
        cases = (
            ("a", True),
            ("1", False),
            ("a1", True),
            (None, False),
            ("", False),
            ("aaaaabbbbbb", True),
            ("AaAaAa", True),
            ("Test 1", False),
            (" ", False),
            (" test", False),
            (" test ", False),
            ("test ", False),
            ("te-st", False),
            ("te_st", False),
            ("te.st", False),
        )
        for raises_exception in (True, False):
            for input_string, expect_valid in cases:
                with self.subTest(
                        "input='{}', raises={}, valid={}".format(input_string, raises_exception, expect_valid)
                ):
                    if expect_valid:
                        self.assertTrue(validate_environment_name(input_string, raises_exception))
                    else:
                        if raises_exception:
                            with self.assertRaises(ValidationError):
                                validate_environment_name(input_string, raises_exception)
                        else:
                            self.assertFalse(validate_environment_name(input_string, raises_exception))

    def test_default_raises(self):
        cases = (None, "", " ", "1")
        for case in cases:
            with self.subTest("case='{}'".format(case)):
                with self.assertRaises(ValidationError):
                    validate_environment_name(case)
