import re
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _


ENVIRONMENT_NAME_PATTERN = re.compile(r'^[a-z][a-z0-9]{0,63}$', re.IGNORECASE)


def validate_environment_name(env: str, raise_on_validation_error: bool = True) -> bool:
    """
    Validate an environment name.

    :param env: The name to check.
    :param raise_on_validation_error: Raise a ValidationError if validation fails.
    :return: True if valid environment name, False otherwise.
    :raises ValidationError: When "raises" is set to True and validation fails.
    """

    if env is None:
        if raise_on_validation_error:
            raise ValidationError(_("Umgebungsname benötigt"))
        return False
    if ENVIRONMENT_NAME_PATTERN.match(env) is not None:
        return True
    else:
        if raise_on_validation_error:
            raise ValidationError(_("Umgebungsname ungültig"))
        return False
