from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from solawi_apps.db_lib.models import NanoIdPkMixin, CreatedMixin, LastModifiedMixin, EnabledMixin, ActiveToMixin, \
    ActiveFromMixin


class Passkey(
    NanoIdPkMixin, CreatedMixin, LastModifiedMixin, ActiveFromMixin, ActiveToMixin, EnabledMixin, models.Model
):

    class Meta:
        verbose_name = _("Passkey")
        verbose_name_plural = _("Passkeys")
        default_permissions = ()
        unique_together = (
            ("owner_fk", "name"),
        )

    name = models.CharField(_("Name"), max_length=255, null=False, blank=False)
    owner_fk = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("Benutzer"), null=False, blank=False, on_delete=models.CASCADE
    )
    credential_id = models.CharField(
        verbose_name=_("Zugangsdaten-ID"), unique=True, null=False, blank=False, max_length=255,
    )
    public_key = models.TextField(verbose_name=_("Öffentlicher Schlüssel"), null=False, blank=False, max_length=100_000)
    backup_state = models.BooleanField(
        verbose_name=_("Sicherungsstatus"), null=True, blank=True, default=None,
    )
    backup_eligibility = models.BooleanField(
        verbose_name=_("Sicherungsberechtigung"), null=True, blank=True, default=None,
    )
    transports = models.CharField(verbose_name=_("Transporte"), null=True, blank=True, default=None, max_length=255)
    sign_count = models.PositiveBigIntegerField(
        verbose_name=_("Unterschriftenzahl"), null=True, blank=True, default=None
    )
