((w, d) => {

    const { startRegistration } = SimpleWebAuthnBrowser;

    const showInitError = (container, error) => {
        const failContainer = container.querySelector('[data-step="fail"]');
        failContainer.querySelector('[data-detail]').innerHTML = error;
        container.querySelectorAll('[data-step]').forEach((s) => {
            s.classList.add("d-none");
        });
        failContainer.classList.remove("d-none");
    };

    const handleResponse = (container, response) => {
        if (response["status"] === "ok") {
            d.location.href = response["next"];
        }
        else {
            showInitError(container, JSON.stringify(response));
        }
    };

    const genKey = (container, config) => {
        startRegistration(config).then((value) => {
            const activeContainer = container.querySelector('[data-step="active"]');
            const verifyUrl = activeContainer.getAttribute("data-verify-url");
            const token = activeContainer.getAttribute("data-token");
            fetch(verifyUrl, {
                method: "post",
                cache: "no-cache",
                headers: {
                    "x-solawi-suite-csrf-token": token,
                    "content-type": "application/json",
                },
                mode: "same-origin",
                body: JSON.stringify(value),
            }).then((value) => {
                if (value.status !== 201) {
                    value.json().then((value) =>  showInitError(container, value["error"])).catch((reason) => showInitError(reason));
                    return;
                }
                value.json().then((value) => {
                   handleResponse(container, value);
                }).catch((reason) => {
                   showInitError(container, reason);
                });
            }).catch((reason) => {
                showInitError(container, reason);
            });
        }).catch((error) => {
            if (error.name === 'InvalidStateError') {
                showInitError(container, "credential already exists");
            }
            else {
                showInitError(container, error)
            }
        });
    };

    const beginGeneration = (container) => {
        container.querySelectorAll('[data-step]').forEach((s) => {
            s.classList.add("d-none");
        });
        const activeContainer = container.querySelector('[data-step="active"]');
        activeContainer.classList.remove("d-none");
        const initUrl = activeContainer.getAttribute("data-init-url");
        const token = activeContainer.getAttribute("data-token");
        fetch(initUrl, {
            method: "post",
            cache: "no-cache",
            headers: {
                "x-solawi-suite-csrf-token": token,
            },
            mode: "same-origin",
            body: null,
        }).then((value) => {
            if (!value.ok) {
                showInitError(container, value.status + " / " + value.statusText);
            }
            else {
                value.json().then((jsonValue) => genKey(container, jsonValue)).catch((reason) => {
                    showInitError(container, reason);
                });
            }
        }).catch((reason) => {
            showInitError(container, reason);
        });
    };

    const checkPasskeysAvailable = (container) => {
        if (
            window.PublicKeyCredential &&
            PublicKeyCredential.isUserVerifyingPlatformAuthenticatorAvailable &&
            PublicKeyCredential.isConditionalMediationAvailable
        ) {
            Promise.all([
                PublicKeyCredential.isUserVerifyingPlatformAuthenticatorAvailable(),
                PublicKeyCredential.isConditionalMediationAvailable(),
            ]).then((results) => {
                console.log(results);
                if (results.every(r => r === true)) {
                    beginGeneration(container);
                }
                else {
                    /*
                    const message = container.querySelector('[data-step="pre"]').getAttribute("data-unsupported-feature-message");
                    if (w.confirm(message)) {
                        beginGeneration(container);
                    }
                    else {
                        showInitError(container, "Feature not available.");
                    }
                    */
                    // Moderne Systeme kriegen das mit einem iPhone oder Android Phone auf die Reihe.
                    beginGeneration(container);
                }
            });
        }
        else {
            showInitError(container, "WebAuthn not available.");
        }
    };

    let passkeyContainer;

    if ((passkeyContainer = d.querySelector('[data-passkey="new"]')) !== null) {
        checkPasskeysAvailable(passkeyContainer);
    }

})(window, document);