from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from solawi_apps.app_permission.models import AccessPermission


class AccessPermissionAdmin(admin.ModelAdmin):

    @admin.display(description=_("Benutzer"), ordering="user_fk__email")
    def get_user(self, obj: AccessPermission):
        return obj.user_fk.email

    @admin.display(description=_("Ist aktuell aktiv"), boolean=True)
    def get_currently_active(self, obj: AccessPermission) -> bool:
        return obj.is_active()

    ordering = ("user_fk__email", "app_name")
    list_filter = ("app_name", "user_fk__email")
    search_fields = ("app_name", "user_fk__email")

    list_display = ("app_name", "get_user", "get_currently_active")

    readonly_fields = ("id", "created", "last_modified")

    fieldsets = (
        (_("Berechtigung"), {
            "fields": ("app_name", "user_fk")
        }),
        (_("Gültigkeit"), {
            "fields": ("enabled", "active_from", "active_to"),
        }),
        (_("Meta"), {
            "fields": ("id", "created", "last_modified"),
        })
    )


class DefaultPermissionAdmin(admin.ModelAdmin):

    @admin.display(description=_("Ist aktuell aktiv"), boolean=True)
    def get_currently_active(self, obj: AccessPermission) -> bool:
        return obj.is_active()

    ordering = ("app_name",)
    list_filter = ("app_name",)
    search_fields = ("app_name",)

    list_display = ("app_name", "get_currently_active")

    readonly_fields = ("id", "created", "last_modified")

    fieldsets = (
        (_("Berechtigung"), {
            "fields": ("app_name",)
        }),
        (_("Gültigkeit"), {
            "fields": ("enabled", "active_from", "active_to"),
        }),
        (_("Meta"), {
            "fields": ("id", "created", "last_modified"),
        })
    )
