from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from solawi_apps.health.models import AccessToken


class AccessTokenAdmin(admin.ModelAdmin):

    ordering = ("id", "created")

    list_display = ("id", "get_currently_active", "enabled", "active_from", "active_to")
    readonly_fields = ("id", "verification_code", "created", "last_modified", "get_currently_active")

    fieldsets = (
        (_("Zugangstoken"), {
            "fields": ("id", "verification_code"),
        }),
        (_("Gültigkeit"), {
            "fields": ("enabled", "active_from", "active_to"),
        }),
        (_("Status"), {
            "fields": ("get_currently_active",),
        }),
        (_("Meta"), {
            "fields": ("created", "last_modified"),
        }),
    )

    def has_add_permission(self, request):
        return False

    @admin.display(description=_("Ist aktuell aktiv"), boolean=True)
    def get_currently_active(self, obj: AccessToken) -> bool:
        return obj.is_active()
