from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from solawi_apps.passkeys.models import Passkey


class PasskeyAdmin(admin.ModelAdmin):

    ordering = ("owner_fk__email", "name", "created")

    list_display = ("name", "get_owner", "get_currently_active", "created")
    list_filter = ("owner_fk__email",)

    search_fields = ("owner_fk__email", "name")

    readonly_fields = (
        "id",
        "created",
        "last_modified",
        "get_owner",
        "get_currently_active",
        "owner_fk",
        "credential_id",
        "public_key",
        "backup_state",
        "backup_eligibility",
        "transports",
        "sign_count",
    )

    fieldsets = (
        (_("Schlüssel"), {
            "fields": ("credential_id", "public_key", "backup_state", "backup_eligibility", "transports", "sign_count"),
        }),
        (_("Besitzer"), {
            "fields": ("owner_fk", "get_owner"),
        }),
        (_("Gültigkeit"), {
            "fields": ("enabled", "active_from", "active_to",),
        }),
        (_("Status"), {
            "fields": ("get_currently_active",),
        }),
        (_("Meta"), {
            "fields": ("id", "created", "last_modified"),
        }),
    )

    @admin.display(description=_("Für Benutzer"), ordering="user_fk__email")
    def get_owner(self, obj: Passkey):
        return obj.owner_fk.email

    @admin.display(description=_("Ist aktuell aktiv"), boolean=True)
    def get_currently_active(self, obj: Passkey) -> bool:
        return obj.is_active()

    def has_add_permission(self, request):
        return False
