from json import dumps

from django.contrib import admin
from django.contrib.admin import ModelAdmin
from django.contrib.sessions.models import Session
from django.utils.html import escape
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _


class SessionAdmin(ModelAdmin):

    ordering = ("-expire_date",)

    search_fields = ("session_key",)

    list_display = (
        "session_key",
        "expire_date",
    )

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "session_key", "get_session_data", "expire_date"
                ),
            },
        ),
    )

    @admin.display(description=_("Sitzungsdaten"))
    def get_session_data(self, obj: Session) -> str:
        data = obj.get_decoded()
        raw_data = dumps(data, indent=2, default=lambda x: str(_("<nicht anzeigbar>")))
        return mark_safe("<pre>{}</pre>".format(escape(raw_data)))

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False
