from django.contrib.admin import AdminSite
from django.contrib.auth import get_user_model
from django.contrib.auth.admin import GroupAdmin, UserAdmin
from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import Group
from django.contrib.sessions.models import Session
from django.utils.translation import gettext_lazy as _

from solawi_apps.announce.models import PublicAnnouncement, MemberAnnouncement
from solawi_apps.app_permission.models import AccessPermission, DefaultPermission
from solawi_apps.health.models import AccessToken
from solawi_apps.passkeys.models import Passkey
from solawi_apps.s_admin.admin.announce import AnnouncementAdmin
from solawi_apps.s_admin.admin.app_permission import AccessPermissionAdmin, DefaultPermissionAdmin
from solawi_apps.s_admin.admin.health import AccessTokenAdmin
from solawi_apps.s_admin.admin.passkeys import PasskeyAdmin
from solawi_apps.s_admin.admin.register import AllowedEmailDomainAdmin, RegistrationAdmin, DomainBasedAppAccessAdmin
from solawi_apps.s_admin.admin.session import SessionAdmin
from solawi_apps.s_admin.admin.txt import TxtFileAdmin
from solawi_apps.s_admin.admin.user import TotpSetupAdmin, AuthAttemptAdmin, AnonAuthAttemptAdmin, BurnedOtpAdmin, \
    UserSessionAdmin, ForgotPasswordAdmin
from solawi_apps.txt.models import TxtFile
from solawi_apps.user.models import AllowedEmailDomain, Registration, TotpSetup, OtpAttempt, LoginAttempt, \
    AuthenticationAttempt, BurnedOtp, UserSession, ForgotPassword, DomainBasedAppAccess


class SolawiSuiteAdminSite(AdminSite):
    site_header = _("[solawi-suite] Administration")
    site_title = _("[solawi-suite] Admin")


admin_site = SolawiSuiteAdminSite()
admin_site.login = login_required(admin_site.login)

admin_site.register(get_user_model(), UserAdmin)
admin_site.register(Group, GroupAdmin)

admin_site.register(Session, SessionAdmin)

admin_site.register(AllowedEmailDomain, AllowedEmailDomainAdmin)
admin_site.register(Registration, RegistrationAdmin)
admin_site.register(DomainBasedAppAccess, DomainBasedAppAccessAdmin)

admin_site.register(TotpSetup, TotpSetupAdmin)
admin_site.register(OtpAttempt, AuthAttemptAdmin)
admin_site.register(LoginAttempt, AuthAttemptAdmin)
admin_site.register(AuthenticationAttempt, AnonAuthAttemptAdmin)
admin_site.register(BurnedOtp, BurnedOtpAdmin)
admin_site.register(UserSession, UserSessionAdmin)
admin_site.register(ForgotPassword, ForgotPasswordAdmin)

admin_site.register(AccessPermission, AccessPermissionAdmin)
admin_site.register(DefaultPermission, DefaultPermissionAdmin)

admin_site.register(TxtFile, TxtFileAdmin)

admin_site.register(PublicAnnouncement, AnnouncementAdmin)
admin_site.register(MemberAnnouncement, AnnouncementAdmin)

admin_site.register(Passkey, PasskeyAdmin)

admin_site.register(AccessToken, AccessTokenAdmin)
