import threading
from os import environ

from django.test import LiveServerTestCase

from selenium.webdriver.firefox.options import Options
from selenium.webdriver.firefox.webdriver import WebDriver


class SeleniumTestCase(LiveServerTestCase):

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.headless = True
        if environ.get('DJANGO_SELENIUM_HEADLESS', None) == "0":
            cls.headless = False
        options = Options()
        if cls.headless:
            options.add_argument('--headless')
        cls.selenium = WebDriver(options)
        cls.selenium.implicitly_wait(10)

    @classmethod
    def tearDownClass(cls):
        cls.selenium.quit()
        for t in threading.enumerate():
            if '(process_request_thread)' in t.name:
                t._args[0].close()
                del t
        super().tearDownClass()
