from django.db import migrations, transaction

FILES = [
    {
        "folder": None,
        "filename": "robots.txt",
        "contents": """
User-Agent: *
Disallow: /
Allow: /static/solawi-suite-manual/
Allow: /handbook/
Allow: /ui/
""".strip(),
    },
    {
        "folder": None,
        "filename": "humans.txt",
        "contents": """
/* TEAM */
    Developer: Jürgen Edelbluth
    Contact: juergen (at) solawi (dot) me
    Instagram: @jrocks.mz
    From: Mainz, Germany
    
/* THANKS */
    QA: All Testers, especially those from Solidarische Landwirtschaft Mainz (https://www.solawi-mainz.de/)
    
/* SITE */
    Doctype: HTML5
    IDE: PyCharm, Affinity Photo, Affinity Designer
    Frameworks: Django, Bootstrap
    About: https://solawi.me/ui/about
""".strip(),
    },
    {
        "folder": None,
        "filename": "ads.txt",
        "contents": "",
    },
    {
        "folder": ".well-known",
        "filename": "security.txt",
        "contents": """
Contact: https://solawi.me/ui/contact
Expires: 2030-12-31T22:59:00.000Z
Encryption: https://openpgpkey.solawi.me/.well-known/openpgpkey/solawi.me/hu/ucn84qqujs41ewuq3tek4s4cfcs7qo4n?l=solawi-suite
Preferred-Languages: de, en
Canonical: https://solawi.me/.well-known/security.txt
""".strip(),
    },
]


def import_files(apps, schema_editor):
    TxtFile = apps.get_model("txt", "TxtFile")
    with transaction.atomic():
        for txt in FILES:
            TxtFile.objects.create(
                folder=txt["folder"],
                filename=txt["filename"],
                content=txt["contents"],
                enabled=True,
            )


class Migration(migrations.Migration):

    dependencies = [
        ('txt', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(import_files),
    ]
