from django.db import models
from django.utils.translation import gettext_lazy as _

from solawi_apps.db_lib.models import NanoIdPkMixin, CreatedMixin, LastModifiedMixin, EnabledMixin


class TxtFile(NanoIdPkMixin, CreatedMixin, LastModifiedMixin, EnabledMixin, models.Model):

    class Meta:
        verbose_name = _("TXT-Datei")
        verbose_name_plural = _("TXT-Dateien")
        unique_together = (
            ("folder", "filename"),
        )

    folder = models.CharField(verbose_name=_("Ordner"), null=True, blank=True, max_length=255)
    filename = models.CharField(verbose_name=_("Dateiname"), null=False, blank=False, max_length=255)
    content = models.TextField(verbose_name=_("Dateiinhalt"), null=False, blank=False, max_length=10_000_000)
    line_endings = models.CharField(verbose_name=_("Zeilenenden"), choices=(
        ("crlf", "crlf"),
        ("lf", "lf"),
    ), blank=False, null=False, default="crlf", max_length=4)

    def __str__(self):
        if self.folder is not None:
            return f"{self.folder}/{self.filename}"
        return self.filename
