from django.http import HttpRequest, HttpResponse, Http404
from django.views import View

from solawi_apps.txt.models import TxtFile


class TxtFileView(View):

    folder = None
    http_method_names = ["get"]
    append_ending = ".txt"

    @staticmethod
    def post_process_txt_file_object(txt_file: TxtFile) -> bytes:
        le = "\r\n" if txt_file.line_endings == "crlf" else "\n"
        return ((le.join(txt_file.content.splitlines(keepends=False))).strip() + le).encode("utf-8")

    def get_folder(self):
        return self.folder

    def get_append_ending(self):
        return self.append_ending

    def get(self, request: HttpRequest, file: str) -> HttpResponse:
        try:
            query = TxtFile.objects.filter(enabled=True)
            if (folder := self.get_folder()) is not None:
                query = query.filter(folder=folder)
            else:
                query = query.filter(folder__isnull=True)
            txt_file = query.get(filename=f"{file}{self.get_append_ending()}")
        except (TxtFile.DoesNotExist, TxtFile.MultipleObjectsReturned):
            raise Http404()
        return HttpResponse(
            content_type="text/plain",
            charset="utf-8",
            content=TxtFileView.post_process_txt_file_object(txt_file),
        )


class RootTxtFileView(TxtFileView):

    pass


class WellKnownTxtFileView(TxtFileView):

    folder = ".well-known"
