ALLOW_ANY = "*"
ALLOW_NONE = "()"
ALLOW_SELF = "self"

DIRECTIVES = (
    ("accelerometer", ALLOW_NONE),
    ("ambient-light-sensor", ALLOW_NONE),
    ("autoplay", ALLOW_NONE),
    ("battery", [ALLOW_SELF]),
    ("bluetooth", ALLOW_NONE),
    ("browser-topics", ALLOW_NONE),
    ("camera", ALLOW_NONE),
    ("display-capture", ALLOW_NONE),
    ("document-domain", ALLOW_NONE),
    ("encrypted-media", ALLOW_NONE),
    ("execution-while-not-rendered", [ALLOW_SELF, '"https://c.solawi.me"']),
    ("execution-while-out-of-viewport", [ALLOW_SELF, '"https://c.solawi.me"']),
    ("fullscreen", [ALLOW_SELF]),
    ("gamepad", ALLOW_NONE),
    ("geolocation", ALLOW_NONE),
    ("gyroscope", ALLOW_NONE),
    ("hid", ALLOW_NONE),
    ("identity-credentials-get", ALLOW_NONE),
    ("idle-detection", ALLOW_NONE),
    ("interest-cohort", ALLOW_NONE),
    ("local-fonts", [ALLOW_SELF]),
    ("magnetometer", ALLOW_NONE),
    ("microphone", ALLOW_NONE),
    ("midi", ALLOW_NONE),
    ("otp-credentials", ALLOW_NONE),
    ("payment", ALLOW_NONE),
    ("picture-in-picture", [ALLOW_SELF]),
    ("publickey-credentials-create", [ALLOW_SELF]),
    ("publickey-credentials-get", [ALLOW_SELF]),
    ("screen-wake-lock", [ALLOW_SELF]),
    ("serial", ALLOW_NONE),
    ("speaker-selection", ALLOW_NONE),
    ("storage-access", [ALLOW_SELF]),
    ("usb", ALLOW_NONE),
    ("web-share", ALLOW_NONE),
    ("window-management", [ALLOW_SELF]),
    ("xr-spatial-tracking", ALLOW_NONE),
)


class PermissionsPolicyMiddleware:

    def __init__(self, get_response):
        self.get_response = get_response
        c_values = []
        for directive, rule in DIRECTIVES:
            if isinstance(rule, str):
                c_values.append(f"{directive}={rule}")
            else:
                c_values.append(f"{directive}=({' '.join(rule)})")
        self.header_value = ', '.join(c_values)

    def __call__(self, request):
        response = self.get_response(request)
        if response.get("Permissions-Policy") is None:
            response["Permissions-Policy"] = self.header_value
        return response
