import string
from typing import Optional

from nanoid import generate


REQUEST_ID_KEY = "solawi_suite_request_id"
REQUEST_ID_HEADER = "X-Solawi-Suite-Request-ID"


def get_request_id(request) -> Optional[str]:
    return getattr(request, REQUEST_ID_KEY, None)


class RequestIdMiddleware:

    def __init__(self, get_response):
        self.get_response = get_response
        self.id_length = 48
        self.id_alphabet = string.digits + string.ascii_lowercase

    def __call__(self, request):
        request_id = generate(self.id_alphabet, self.id_length)
        setattr(request, REQUEST_ID_KEY, request_id)
        response = self.get_response(request)
        response[REQUEST_ID_HEADER] = get_request_id(request)
        return response
