import re
from typing import Optional, Literal

from django.http import HttpRequest


VALID_URL_PATTERN = re.compile("^(/$)|(/[^/])", re.ASCII | re.IGNORECASE)


def get_nav_url(request: HttpRequest, mode: Literal["from", "next"]) -> Optional[str]:
    if (url := request.GET.get(mode, None)) is not None:
        if VALID_URL_PATTERN.match(url) is not None:
            return url
    return None


def get_next_url(request: HttpRequest) -> Optional[str]:
    return get_nav_url(request, mode="next")


def get_from_url(request: HttpRequest) -> Optional[str]:
    return get_nav_url(request, mode="from")
