from django import template, forms

register = template.Library()


@register.filter(name="form_control")
def form_control(form_field: forms.BoundField) -> forms.BoundField:
    current_classes = form_field.field.widget.attrs.get("class")
    if current_classes is None:
        current_classes = ""
    if "form-control" in current_classes:
        return form_field
    form_field.field.widget.attrs["class"] = f"form-control {current_classes}".strip()
    return form_field


@register.filter(name="autofocus")
def autofocus(form_field: forms.BoundField) -> forms.BoundField:
    form_field.field.widget.attrs["autofocus"] = True
    return form_field


@register.filter(name="monospace")
def monospace(form_field: forms.BoundField) -> forms.BoundField:
    current_classes = form_field.field.widget.attrs.get("class")
    if current_classes is None:
        current_classes = ""
    if "font-monospace" in current_classes:
        return form_field
    form_field.field.widget.attrs["class"] = f"{current_classes} font-monospace".strip()
    return form_field


@register.filter(name="decimal_field")
def decimal_field(form_field: forms.BoundField, decimal_places: int = 2) -> forms.BoundField:
    current_classes = form_field.field.widget.attrs.get("class")
    if current_classes is None:
        current_classes = ""
    if "text-end" not in current_classes:
        current_classes += " text-end"
    form_field.field.widget.attrs["class"] = current_classes.strip()
    steps = "."
    while len(steps) < decimal_places:
        steps += "0"
    steps += "1"
    form_field.field.widget.attrs["step"] = steps
    form_field.field.widget.attrs["pattern"] = fr"^\d+,\d{{{decimal_places:d}}}$"
    form_field.field.widget.attrs["data-decimals"] = decimal_places
    return form_field


@register.filter(name="textarea_rows")
def textarea_rows(form_field: forms.BoundField, rows: int = 10) -> forms.BoundField:
    form_field.field.widget.attrs["rows"] = rows
    return form_field


@register.filter(name="textarea_cols")
def textarea_rows(form_field: forms.BoundField, cols: int = 60) -> forms.BoundField:
    form_field.field.widget.attrs["cols"] = cols
    return form_field
