import datetime
from typing import Union, Optional

from django import template
from django.conf import settings
from django.http import HttpRequest
from django.utils.html import escape
from django.utils.safestring import SafeString, mark_safe
from django.utils.timezone import now
from markdown import Markdown

register = template.Library()


@register.inclusion_tag(
    "solawi_apps/ui/tags/solawi_ui/title_separator.html",
    name="title_sep",
    takes_context=False,
)
def get_title_separator() -> dict:
    return {}


@register.filter(name="as_absolute_url")
def as_absolute_url(url: str, request: HttpRequest) -> str:
    return request.build_absolute_uri(url)


@register.simple_tag(name="app_version", takes_context=False)
def get_app_version() -> str:
    return settings.APP_VERSION


@register.filter(name="group_by")
def group_by(in_str: str, group_by_chars: int = 3) -> SafeString:
    final_string = ""
    count = 0
    for char in in_str:
        count += 1
        final_string += escape(char)
        if count >= group_by_chars:
            count = 0
            final_string += "&nbsp;"
    if final_string.endswith("&nbsp;"):
        final_string = final_string[:-6]
    return mark_safe(final_string.strip())


@register.filter(name="dt_gt")
def datetime_is_greater_than(
    dt: Union[datetime.datetime, datetime.date], ref: Optional[datetime.datetime] = None
) -> bool:
    if ref is None:
        ref = now()
    return dt > ref


@register.filter(name="dt_lt")
def datetime_is_greater_than(
    dt: Union[datetime.datetime, datetime.date], ref: Optional[datetime.datetime] = None
) -> bool:
    if ref is None:
        ref = now()
    return dt < ref


@register.filter(name="copyable_grouping")
def copyable_grouping(in_str: str) -> SafeString:
    out = ""
    index = 0
    for split in in_str.split("&nbsp;"):
        classes = []
        if index > 0:
            classes.append("ml")
        index += 1
        if index < len(in_str):
            classes.append("mr")
        classes = " ".join(classes)
        out += f'<span class="{classes.strip()}">{escape(split)}</span>'
    return mark_safe(out)


@register.filter(name="markdown")
def render_markdown(
    md: str,
    extensions: str = "toc,fenced_code,tables,footnotes,sane_lists,smarty,extra,admonition,abbr,attr_list",
) -> SafeString:
    return mark_safe(Markdown(output_format="html", extensions=[t.strip() for t in extensions.split(",")]).convert(md))
