from django.test import TestCase

from bs4 import BeautifulSoup


class SocialMediaCardsTestCase(TestCase):

    def test_urls_are_absolute(self):
        tags_with_abs_urls = (
            'meta[property="og:url"]',
            'meta[name="twitter:url"]',
        )
        pages_to_test = (
            '/ui/contact',
            '/ui/welcome',
            '/ui/impressum',
            '/ui/about',
        )
        for page in pages_to_test:
            with self.subTest(page=page):
                result = self.client.get(page)
                self.assertEqual(result.status_code, 200)
                soup = BeautifulSoup(result.content.decode(result.charset), features="html5lib")
                for tag in tags_with_abs_urls:
                    with self.subTest(tag=tag):
                        meta_tag = soup.css.select(f"head {tag}")
                        self.assertIsNotNone(meta_tag)
                        self.assertEqual(len(meta_tag), 1)
                        meta_tag = meta_tag[0]
                        content = meta_tag.attrs["content"]
                        self.assertEqual(content, f"http://testserver{page}")

    def test_no_cards_when_404(self):
        some_tags = (
            'meta[property^="og:"]',
            'meta[name^="twitter:"]',
        )
        result = self.client.get("/does/not/exist")
        self.assertEqual(result.status_code, 404)
        soup = BeautifulSoup(result.content.decode(result.charset), features="html5lib")
        for tag in some_tags:
            with self.subTest(tag=tag):
                meta_tag = soup.css.select(f"head {tag}")
                self.assertEqual(len(meta_tag), 0)
