from builtins import Exception
from typing import Optional

from django.conf import settings
from django.http import HttpRequest, HttpResponse
from django.shortcuts import render
from django.views.csrf import csrf_failure, CSRF_FAILURE_TEMPLATE_NAME
from django.views.defaults import page_not_found, server_error, ERROR_500_TEMPLATE_NAME, ERROR_404_TEMPLATE_NAME, \
    ERROR_403_TEMPLATE_NAME, permission_denied, ERROR_400_TEMPLATE_NAME, bad_request


def handle404(request: HttpRequest, exception: Exception, template_name=ERROR_404_TEMPLATE_NAME) -> HttpResponse:
    if settings.DEBUG:
        return page_not_found(request, exception, template_name)
    return render(request, "solawi_apps/ui/errors/404.html", context={
        "r": request,
        "e": exception,
        "is_exception": True,
    }, status=404)


def handle500(request: HttpRequest, template_name=ERROR_500_TEMPLATE_NAME) -> HttpResponse:
    if settings.DEBUG:
        return server_error(request, template_name)
    return render(request, "solawi_apps/ui/errors/500.html", context={
        "r": request,
        "is_exception": True,
    }, status=500)


def handle403(request: HttpRequest, exception: Exception, template_name=ERROR_403_TEMPLATE_NAME) -> HttpResponse:
    if settings.DEBUG:
        return permission_denied(request, exception, template_name)
    return render(request, "solawi_apps/ui/errors/403.html", context={
        "r": request,
        "e": exception,
        "is_exception": True,
    }, status=403)


def handle400(request: HttpRequest, exception: Exception, template_name=ERROR_400_TEMPLATE_NAME) -> HttpResponse:
    if settings.DEBUG:
        return bad_request(request, exception, template_name)
    return render(request, "solawi_apps/ui/errors/400.html", context={
        "r": request,
        "e": exception,
        "is_exception": True,
    }, status=400)


def handle403_csrf(
    request: HttpRequest, reason: Optional[str] = "", template_name=CSRF_FAILURE_TEMPLATE_NAME
) -> HttpResponse:
    if settings.DEBUG:
        return csrf_failure(request, reason, template_name)
    return render(request, "solawi_apps/ui/errors/csrf.html", context={
        "r": request,
        "is_exception": True,
    }, status=403)
