from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
from django.http import Http404
from django.views.generic import FormView

from solawi_apps.ui.forms.dummy import DummyForm


class ConfirmationView(FormView):

    form_class = DummyForm
    pk_url_kwarg = 'pk'
    model = None
    queryset = None
    object = None

    __internal_form_key = "__internal_form_key__"

    def get_queryset(self):
        if self.queryset is not None:
            return self.queryset
        if self.model is not None:
            return self.model.objects.all()

    def action(self):
        return super().form_valid(self)

    def form_valid(self, form):
        setattr(self, self.__internal_form_key, form)
        return self.action()

    def get_object(self):
        if self.object is None:
            self.object = self.get_queryset().get(pk=self.kwargs.get(self.pk_url_kwarg))
        return self.object

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        try:
            context["object"] = self.get_object()
        except (ObjectDoesNotExist, MultipleObjectsReturned):
            raise Http404()
        return context
