import re

from django.core.validators import RegexValidator
from django.forms import forms, EmailField, CharField, PasswordInput
from django.utils.translation import gettext_lazy as _

from solawi_apps.user.otp import make_otp_input_field


class LoginForm(forms.Form):

    username = EmailField(
        label=_("Benutzername"),
        help_text=_("In der Regel ist das deine E-Mail-Adresse."),
        required=True,
    )
    username.widget.attrs.update(
        {'placeholder': _("du@deine-solawi.local")}
    )
    password = CharField(
        widget=PasswordInput, required=True, min_length=10, max_length=1024, label=_("Passwort"),
    )


class OtpForm(forms.Form):

    otp = make_otp_input_field(
        help_text=_("Bitte gib das Einmal-Passwort ein, welches deine TOTP-Anwendung erzeugt hat.")
    )


class EmergencyCodeForm(forms.Form):

    emergency_code = CharField(
        required=True, max_length=16, min_length=16, label=_("Notfallcode"), strip=True, validators=[
            RegexValidator(regex=r"^[A-Z0-9]{16}$", flags=re.ASCII),
        ],
        help_text=_("Bitte gib einen Notfallcode ein, den du bisher noch nicht verwendet hast. "
                    "Achte dabei auf Groß- und Kleinschreibung."),
    )
