from argparse import ArgumentParser

from django.conf import settings
from django.core.exceptions import ValidationError
from django.core.management import BaseCommand, CommandError
from django.core.validators import validate_email
from django.urls import reverse
from django.utils.translation import gettext_lazy as _

from solawi_apps.user.registration import register_user


class Command(BaseCommand):

    help = _("Erstelle einen Superuser")

    def add_arguments(self, parser: ArgumentParser):
        parser.add_argument("email", type=str, nargs="?", help=_("E-Mail-Adresse"))

    def handle(self, *args, **options):
        if (emails := options.get("email")) is None:
            email = input(f"{_('E-Mail-Adresse')}: ").strip().lower()
        else:
            email = emails.strip().lower()
        try:
            validate_email(email)
        except ValidationError as err:
            raise CommandError(_("email ungültig")) from err
        try:
            registration = register_user(email, as_superuser=True)
        except ValueError as err:
            raise CommandError(' / '.join([str(e) for e in err.args])) from err
        reg_url = reverse(
            "user:register.register", kwargs={
                "internal_user": registration.internal_username,
                "registration_id": registration.registration_id,
                "registration_check": registration.registration_check,
            }
        )
        self.stdout.write(f'{self.style.SUCCESS(_("Erfolg:"))} {settings.URL_BASE}{reg_url}')
