from django.core.management import BaseCommand
from django.utils.translation import gettext_lazy as _

from solawi_apps.user.models import TotpSetup
from solawi_apps.user.otp import get_totp_object, get_secret


class Command(BaseCommand):

    help = _("Erzeuge ein Einmalpasswort für einen Benutzer")

    def add_arguments(self, parser):
        parser.add_argument("email", type=str, nargs="?", help=_("E-Mail-Adresse"))

    def handle(self, *args, **options):
        if (email := options.get("email")) is None:
            email = input(f"{_('E-Mail-Adresse')}: ").strip().lower()
        totp = TotpSetup.objects.filter(
            user_fk__email__iexact=email,
        ).only("totp_provisioning").get()
        totp_obj = get_totp_object(get_secret(totp.totp_provisioning))
        self.stdout.write(f'{self.style.SUCCESS(_("Erfolg:"))} {totp_obj.now()}')
