import datetime
import django.db.models.deletion
import solawi_apps.db_lib.dbid
import solawi_apps.db_lib.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AllowedEmailDomain',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('active_from', models.DateTimeField(default=datetime.datetime(2000, 1, 1, 0, 0, tzinfo=datetime.timezone.utc), verbose_name='Aktiv ab')),
                ('active_to', models.DateTimeField(default=datetime.datetime(2999, 12, 31, 23, 59, 59, 999999, tzinfo=datetime.timezone.utc), verbose_name='Aktiv bis')),
                ('domain', models.CharField(max_length=255, verbose_name='Domain')),
            ],
            options={
                'verbose_name': 'Zugelassene Domain',
                'verbose_name_plural': 'Zugelassene Domains',
            },
        ),
        migrations.CreateModel(
            name='OtpAttempt',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('success', models.BooleanField(default=False, editable=False, verbose_name='Erfolgreicher Versuch')),
                ('user_fk', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'OTP-Versuch',
                'verbose_name_plural': 'OTP-Versuche',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Registration',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('enabled', models.BooleanField(default=False, verbose_name='Aktiviert')),
                ('active_from', models.DateTimeField(default=datetime.datetime(2000, 1, 1, 0, 0, tzinfo=datetime.timezone.utc), verbose_name='Aktiv ab')),
                ('active_to', models.DateTimeField(default=datetime.datetime(2999, 12, 31, 23, 59, 59, 999999, tzinfo=datetime.timezone.utc), verbose_name='Aktiv bis')),
                ('as_superuser', models.BooleanField(default=False, editable=False, verbose_name='Registrierung als Superuser')),
                ('registration_id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, unique=True, verbose_name='Registrierungs-ID')),
                ('registration_check', solawi_apps.db_lib.models.EncryptedTextField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, verbose_name='Registrierungs-Check')),
                ('registration_finished', models.BooleanField(default=False, verbose_name='Registrierung abgeschlossen')),
                ('user_fk', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Registrierung',
                'verbose_name_plural': 'Registrierungen',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TotpSetup',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert')),
                ('totp_provisioning', solawi_apps.db_lib.models.EncryptedTextField(editable=False, max_length=1024, verbose_name='TOTP Provisionierung')),
                ('user_fk', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'TOTP Setup',
                'verbose_name_plural': 'TOTP Setups',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='BurnedOtp',
            fields=[
                ('id', models.CharField(default=solawi_apps.db_lib.dbid.generate_id, editable=False, max_length=32, primary_key=True, serialize=False, validators=[solawi_apps.db_lib.dbid.validate_nanoid], verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Erstellt')),
                ('otp', models.CharField(editable=False, max_length=6, verbose_name='Einmalpasswort')),
                ('totp_setup_fk', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to='user.totpsetup', verbose_name='TOTP Setup')),
            ],
            options={
                'verbose_name': 'Verbranntes Einmalpasswort',
                'verbose_name_plural': 'Verbrannte Einmalpasswörter',
                'default_permissions': (),
                'unique_together': {('totp_setup_fk', 'otp')},
            },
        ),
    ]
