from django.urls import path, register_converter

from solawi_apps.db_lib.dbid import NanoIdConverter
from solawi_apps.user.views.auth import LoginView, LogoutView, OtpView, LogoutAllSessionsView, EmergencyCodeView
from solawi_apps.user.views.manage import AccountManageView, ChangePasswordView, ChangeOtpView, ChangeOtpQrCodeView, \
    ForgotPasswordView, ResetPasswordView, EmergencyCodeRegenView
from solawi_apps.user.views.register import StartRegisterMeView, RegisterMeView, StartRegisterMeSuccessView, \
    RegisterTotpQrCodeView

register_converter(NanoIdConverter, "nanoid")

urlpatterns = [
    path("register", StartRegisterMeView.as_view(), name="register.start"),
    path("register/success", StartRegisterMeSuccessView.as_view(), name="register.start.success"),
    path(
        "register/<uuid:internal_user>/<nanoid:registration_id>/<nanoid:registration_check>",
        RegisterMeView.as_view(),
        name="register.register"
    ),
    path(
        "register/<uuid:internal_user>/<nanoid:registration_id>/<nanoid:registration_check>/<nanoid:otp>",
        RegisterTotpQrCodeView.as_view(),
        name="register.register.qr"
    ),
    path("auth/login", LoginView.as_view(), name="auth.login"),
    path("auth/logout", LogoutView.as_view(), name="auth.logout"),
    path("auth/logout-all", LogoutAllSessionsView.as_view(), name="auth.logout-all"),
    path("auth/otp", OtpView.as_view(), name="auth.otp"),
    path("auth/emergency-code", EmergencyCodeView.as_view(), name="auth.emergency-code"),
    path("self-service", AccountManageView.as_view(), name="manage"),
    path("self-service/password", ChangePasswordView.as_view(), name="manage.password"),
    path("self-service/otp-secret", ChangeOtpView.as_view(), name="manage.otp-secret"),
    path("self-service/otp-secret/qr-code", ChangeOtpQrCodeView.as_view(), name="manage.otp-secret.qr-code"),
    path("self-service/forgot-password", ForgotPasswordView.as_view(), name="manage.forgot-password"),
    path(
        "self-service/forgot-password/<str:salt>/<str:data>",
        ResetPasswordView.as_view(),
        name="manage.forgot-password.reset",
    ),
    path("self-service/emergency-codes", EmergencyCodeRegenView.as_view(), name="manage.emergency-codes"),
]
app_name = 'solawi_apps.user'
