import os
from datetime import timedelta
from pathlib import Path

from corsheaders.defaults import default_headers
from django.contrib import messages
from django.conf.global_settings import STORAGES as DEFAULT_STORAGES
from django.urls import reverse_lazy
from django.utils.translation import gettext_lazy as _

from solawi_apps.encrypted_settings.crypt import decrypt_item
from solawi_platform.initlib import get_version

SETTINGS_MODULE = 'solawi_platform.settings'
OS_SETTINGS_MODULE = os.environ.get("DJANGO_SETTINGS_MODULE", SETTINGS_MODULE)

APP_VERSION = get_version()

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

PUBLIC_KEY_DIR = BASE_DIR / 'keys'
URL_BASE = "http://127.0.0.1:8000"

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/5.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = decrypt_item(
    'BJwLkif_UXgkDwi4EtJAjPWI_5Xxocz41g9BXfz4ApHtaU1AUWRKaLSNH97Y9puTgjTHKTSoGEF-ns0ak3f4g6C9bocK'
    'vPMhVBYHUDa5oA_Up_zSyZeNlYtU5wK_3CmyMygEpO1Sa_lEW5XMk4a0xa_oFwJwwyhmVSiGb9SmKR6o-LUN4OT5GDZD'
    'fxDVAsiT8sDfgTrtKfQazCVwz6tzj7pyaag76WtVj_L-4LilwP80SEor',
    no_raise=SETTINGS_MODULE != OS_SETTINGS_MODULE
)

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = os.environ.get("SOLAWI_SUITE_DEBUG", None) != "0"

ALLOWED_HOSTS = [
    "localhost",
    "127.0.0.1",
]
INTERNAL_IPS = [
    "127.0.0.1",
]

ADMINS = [
    (
        decrypt_item("BEReCru8P1XY7zzwKa6IJEkmwq7-cBnMZJ2T0dbGeUGb3RMXdlBvnsCWvRfumX0hKAlTIGlRirGKi-nJwUvWkOzu5DBJIPJN"
                     "fnVpiBWciA7iUPV90bJAbvfte-b1tEIK4Z2GWvbdWLM=",
                     no_raise=SETTINGS_MODULE != OS_SETTINGS_MODULE),
        decrypt_item("BDQ2ZbHq5WBWeCzRjRvYz8aBFFTKu0N5cHiN5-p2vH8uE9zSSYbEwpywmyRmHpfrmGeXNJZ0gvLJfPm5WNYjH9pVQwsLnFgW"
                     "-ZHwgspXZ0cgDcRulvf1plsYkPlNcEZa3FzbD91t0-jFbW_VXbuk2pI=",
                     no_raise=SETTINGS_MODULE != OS_SETTINGS_MODULE),
    ),
    (
        decrypt_item("BGlYrRrma4AwMWDp8Bel_kuVbZyqTKMnLMcDC8vvqidwAOJaOOtHnfUIgAhZ9EjdB00Cnnf5vHSWUrfBlZkEmumDK58O4u8t"
                     "PTeDQdy1JGDXvVNiYQ3r-Tlc8RKkCyjKBZrWJI7JlQQ=",
                     no_raise=SETTINGS_MODULE != OS_SETTINGS_MODULE),
        decrypt_item("BHE2XqpZEOhIymfwhI5sAS4khnVtUd0lAJ-mroPzLBjGc5K-_7kNoonld9he6E5OX3fmTPGa3wFIiwd3OV_y0ZonFCGA4Hbl"
                     "DRTlHKg79hIG2JGIQlYlFDQndaDhGYzt3mgp3xK-iqf6AxGgRTApEwA=",
                     no_raise=SETTINGS_MODULE != OS_SETTINGS_MODULE),
    ),
]

MANAGERS = ADMINS

# Application definition

INSTALLED_APPS = [
    'solawi_apps.testing',
    'daphne',
    'corsheaders',
    'django_eventstream',
    'solawi_apps.s_admin',
    'solawi_apps.ui',
    'solawi_apps.encrypted_settings',
    'solawi_apps.url',
    'solawi_apps.db_lib',
    'solawi_apps.user',
    'solawi_apps.handbook',
    'solawi_apps.bidding',
    'solawi_apps.ahg',
    'solawi_apps.beamer',
    'solawi_apps.changelog',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.humanize',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.sitemaps',
    'whitenoise.runserver_nostatic',
    'django.contrib.staticfiles',
    'debug_toolbar',
    'requests_tracker',
    'solawi_apps.app_permission',
    'solawi_apps.txt',
    'solawi_apps.passkeys',
    'solawi_apps.announce',
    'solawi_apps.health',
    'health_check',  # required
    'health_check.db',  # stock Django health checkers
    'health_check.cache',
    'health_check.storage',
    'health_check.contrib.migrations',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'solawi_apps.ui.middleware.request_id.RequestIdMiddleware',
    'solawi_apps.health.middleware.HealthCheckApiAuthMiddleware',
    'corsheaders.middleware.CorsMiddleware',
    'csp.middleware.CSPMiddleware',
    'debug_toolbar.middleware.DebugToolbarMiddleware',
    'requests_tracker.middleware.requests_tracker_middleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'whitenoise.middleware.WhiteNoiseMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'solawi_apps.user.middleware.emergency_code.EmergencyCodeMiddleware',
    'solawi_apps.passkeys.middleware.NoPasskeyAvailableMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'solawi_apps.ui.middleware.xss_filter.XssFilterMiddleware',
    'solawi_apps.ui.middleware.permissions_policy.PermissionsPolicyMiddleware',
    'solawi_apps.ui.middleware.access.AccessControlAllowOriginMiddleware',
]

ROOT_URLCONF = 'solawi_platform.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'solawi_platform.wsgi.application'
ASGI_APPLICATION = 'solawi_platform.asgi.application'

# Database
# https://docs.djangoproject.com/en/5.0/ref/settings/#databases

DATABASE_FILE = os.environ.get("DJANGO_DATABASE_FILE", BASE_DIR / 'db.sqlite3')

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': DATABASE_FILE,
    }
}


# Password validation
# https://docs.djangoproject.com/en/5.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/5.0/topics/i18n/

LANGUAGE_CODE = 'de-de'
TIME_ZONE = 'Europe/Berlin'
USE_I18N = True
USE_TZ = True
DEFAULT_CHARSET = 'utf-8'


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/5.0/howto/static-files/

STATIC_URL = 'static/'
STATIC_ROOT = BASE_DIR / '_compiled_static_files'
STATICFILES_DIRS = [
    BASE_DIR / "3rdparty" / "node_modules",
    BASE_DIR / "documentation" / "site",
]


# Default primary key field type
# https://docs.djangoproject.com/en/5.0/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

MESSAGE_STORAGE = "django.contrib.messages.storage.session.SessionStorage"
MESSAGE_TAGS = {
    messages.DEBUG: "alert-secondary",
    messages.INFO: "alert-info",
    messages.WARNING: "alert-warning",
    messages.SUCCESS: "alert-success",
    messages.ERROR: "alert-danger",
}


STORAGES = DEFAULT_STORAGES
STORAGES.update({
    "staticfiles": {
        "BACKEND": "django.contrib.staticfiles.storage.StaticFilesStorage",
    }
})

AVAILABLE_SOLAWI_SUITE_APPS = (
    (
        "solawi_apps.bidding",
        _("Digitales Gebot"),
        "fa-solid fa-money-bill-wheat",
        reverse_lazy("solawi_apps.bidding:events"),
    ),
    (
        "solawi_apps.ahg",
        _("Abholgemeinschaft"),
        "fa-solid fa-people-carry-box",
        reverse_lazy("solawi_apps.ahg:list"),
    ),
    (
        "solawi_apps.beamer",
        _("Beamer-Verbindung"),
        "fa-solid fa-person-chalkboard",
        reverse_lazy("solawi_apps.beamer:connections"),
    ),
)

EMAIL_BACKEND = "django.core.mail.backends.filebased.EmailBackend"
EMAIL_FILE_PATH = os.environ.get("DJANGO_EMAIL_DIR", BASE_DIR / "_email")

SERVER_EMAIL = "solawi-suite@solawi.me"
DEFAULT_FROM_EMAIL = SERVER_EMAIL

EMAIL_SUBJECT_PREFIX = "[solawi-suite] "

ONLY_ALLOWED_DOMAINS_FOR_REGISTRATION = True

APPEND_SLASH = False

LOGIN_URL = reverse_lazy("user:auth.login")
LOGOUT_URL = reverse_lazy("user:auth.logout")

LOGOUT_REDIRECT_URL = reverse_lazy("solawi_apps.ui:welcome")
LOGIN_REDIRECT_URL = reverse_lazy("solawi_apps.ui:welcome")


FILE_UPLOAD_HANDLERS = [
    "django.core.files.uploadhandler.MemoryFileUploadHandler",
    "django.core.files.uploadhandler.TemporaryFileUploadHandler",
]

EVENTSTREAM_STORAGE_CLASS = 'django_eventstream.storage.DjangoModelStorage'
EVENTSTREAM_CHANNELMANAGER_CLASS = 'solawi_apps.beamer.channel.BeamerChannelManager'

DECIMAL_SEPARATOR = ","
THOUSAND_SEPARATOR = "."
USE_THOUSAND_SEPARATOR = True
NUMBER_GROUPING = 3
FIRST_DAY_OF_WEEK = 1

PREPEND_WWW = False

CSRF_COOKIE_PATH = "/"
CSRF_COOKIE_AGE = None
CSRF_COOKIE_NAME = "solawi_suite.csrf"
CSRF_COOKIE_SAMESITE = "Lax"
CSRF_COOKIE_SECURE = False
CSRF_USE_SESSIONS = True
CSRF_COOKIE_HTTPONLY = True
CSRF_HEADER_NAME = "HTTP_X_SOLAWI_SUITE_CSRF_TOKEN"

LANGUAGE_COOKIE_AGE = None
LANGUAGE_COOKIE_PATH = "/"
LANGUAGE_COOKIE_HTTPONLY = True
LANGUAGE_COOKIE_NAME = "solawi_suite.language"
LANGUAGE_COOKIE_SAMESITE = "Lax"
LANGUAGE_COOKIE_SECURE = False

SESSION_COOKIE_AGE = timedelta(days=2).total_seconds()
SESSION_COOKIE_HTTPONLY = True
SESSION_COOKIE_NAME = "solawi_suite.session"
SESSION_COOKIE_PATH = "/"
SESSION_COOKIE_SAMESITE = "Lax"
SESSION_COOKIE_SECURE = False
SESSION_EXPIRE_AT_BROWSER_CLOSE = True

MATOMO_SITE_ID = "2"

SOLAWI_SUITE_DEFAULT_CSP_POLICY = ["'self'"]
CSP_BASE_URI = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_DEFAULT_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_SCRIPT_SRC = [*SOLAWI_SUITE_DEFAULT_CSP_POLICY, 'c.solawi.me']
CSP_IMG_SRC = [*SOLAWI_SUITE_DEFAULT_CSP_POLICY, 'c.solawi.me', 'data:']
CSP_OBJECT_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_MEDIA_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_FRAME_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_FONT_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_CONNECT_SRC = [*SOLAWI_SUITE_DEFAULT_CSP_POLICY, 'c.solawi.me']
CSP_STYLE_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_CHILD_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_FORM_ACTION = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_MANIFEST_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_WORKER_SRC = SOLAWI_SUITE_DEFAULT_CSP_POLICY
CSP_UPGRADE_INSECURE_REQUESTS = False
CSP_FRAME_ANCESTORS = SOLAWI_SUITE_DEFAULT_CSP_POLICY

CSP_EXCLUDE_URL_PREFIXES = (
    "/static/solawi-suite-manual/",
    "/__requests_tracker__/",
)

SECURE_CONTENT_TYPE_NOSNIFF = True
SECURE_CROSS_ORIGIN_OPENER_POLICY = "same-origin"
SECURE_REDIRECT_EXEMPT = []
SECURE_SSL_REDIRECT = False
SECURE_REFERRER_POLICY = 'strict-origin'
SECURE_BROWSER_XSS_FILTER = True

X_FRAME_OPTIONS = "SAMEORIGIN"

TEST_ORIGIN = os.environ.get("SOLAWI_SUITE_TEST_ORIGIN", None)

CORS_ALLOWED_ORIGINS = (
    "http://localhost:8080",
    "http://127.0.0.1:8000",
)
if TEST_ORIGIN is not None:
    CORS_ALLOWED_ORIGINS = (TEST_ORIGIN, *CORS_ALLOWED_ORIGINS)

CORS_ALLOW_ALL_ORIGINS = False
CORS_ALLOW_HEADERS = (
    *default_headers,
    "x-solawi-suite-csrf-token",
    "x-solawi-suite-access-token",
)
CORS_ALLOW_CREDENTIALS = False
ACCESS_CONTROL_ALLOW_ORIGIN = None

CSRF_FAILURE_VIEW = "solawi_apps.ui.views.errors.handle403_csrf"

WHITENOISE_ALLOW_ALL_ORIGINS = False
WHITENOISE_KEEP_ONLY_HASHED_FILES = False

EMERGENCY_CODE_WARNING_THRESHOLD = 5
EMERGENCY_CODE_ALERT_THRESHOLD = 2

PASSKEYS_RELYING_PARTY = {
    "name": "[solawi-suite development]",
    "id": "localhost",
}
PASSKEYS_EXPECTED_ORIGINS = [
    "http://localhost:8000",
]
if TEST_ORIGIN is not None:
    PASSKEYS_EXPECTED_ORIGINS.append(TEST_ORIGIN)

HEALTH_CHECK = {
    'DISK_USAGE_MAX': 80,  # percent
}

HEALTH_CHECK_ACCESS_TOKEN_HEADER = "x-solawi-suite-access-token"
