"""
URL configuration for solawi_platform project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
import secrets

from django.conf import settings
from django.contrib.sitemaps.views import sitemap
from django.templatetags.static import static
from django.urls import path, include, reverse_lazy
from django.views.generic import RedirectView

from solawi_apps.s_admin.admin.site import admin_site
from solawi_platform.sitemaps import get_sitemaps

urlpatterns = [
    path('admin/doc/', include('django.contrib.admindocs.urls')),
    path('admin/', admin_site.urls),
    path('users/', include('solawi_apps.user.urls', namespace="user")),
    path('passkey/', include('solawi_apps.passkeys.urls', namespace="passkey")),
    path('ui/', include('solawi_apps.ui.urls', namespace="ui")),
    path('handbook/', include('solawi_apps.handbook.urls', namespace="handbook")),
    path('beamer/', include('solawi_apps.beamer.urls', namespace="beamer")),
    path('bid/', include("solawi_apps.bidding.urls", namespace="bidding")),
    path('ahg/', include("solawi_apps.ahg.urls", namespace="ahg")),
    path('access/', include("solawi_apps.app_permission.urls", namespace="access")),
    path('changelog/', include("solawi_apps.changelog.urls", namespace="changelog")),
    path('health/', include("solawi_apps.health.urls", namespace="health")),
    path(
        'favicon.png',
        RedirectView.as_view(
            url=static("solawi_apps/ui/favicon.png"),
            permanent=False,
        ), name="favicon.png",
    ),
    path(
        'favicon.ico',
        RedirectView.as_view(
            url=static("solawi_apps/ui/favicon/favicon.ico"),
            permanent=False,
        ), name="favicon.ico",
    ),
    path("sitemaps/sitemap.xml", sitemap, {"sitemaps": get_sitemaps()}, name="django.contrib.sitemaps.views.sitemap"),
    path('', include("solawi_apps.txt.urls", namespace="txt")),
    path('', RedirectView.as_view(url=reverse_lazy("solawi_apps.ui:welcome"), permanent=False), name="index"),
]

if settings.DEBUG:
    urlpatterns.insert(0, path(f"__debug__{secrets.token_hex(16)}__/", include("debug_toolbar.urls")))
    urlpatterns.insert(0, path("__requests_tracker__/", include("requests_tracker.urls")))


handler404 = "solawi_apps.ui.views.errors.handle404"
handler500 = "solawi_apps.ui.views.errors.handle500"
handler403 = "solawi_apps.ui.views.errors.handle403"
handler400 = "solawi_apps.ui.views.errors.handle400"
