from datetime import datetime, timezone

from faker import Faker
from faker.providers import internet, misc
from robot.api.deco import keyword


class RandomTestDataLib:

    ROBOT_LIBRARY_SCOPE = 'GLOBAL'
    ROBOT_LIBRARY_VERSION = '0.1.0'

    def __init__(self):
        self.faker = Faker('de_DE')
        self.faker.add_provider(internet)
        self.faker.add_provider(misc)

    @keyword("Get Random E-Mail Address")
    def get_random_email(self) -> str:
        return self.faker.ascii_company_email()

    @keyword("Get Random Password")
    def get_random_password(self) -> str:
        return self.faker.password(length=16)

    @keyword("Get Random First Name")
    def get_random_first_name(self) -> str:
        return self.faker.first_name()

    @keyword("Get Random Last Name")
    def get_random_last_name(self) -> str:
        return self.faker.last_name()


class TimingLib:

    ROBOT_LIBRARY_SCOPE = 'GLOBAL'
    ROBOT_LIBRARY_VERSION = '0.1.0'

    @keyword("Now")
    def get_now(self) -> datetime:
        return datetime.now(tz=timezone.utc)


class DataLib:

    ROBOT_LIBRARY_SCOPE = 'GLOBAL'
    ROBOT_LIBRARY_VERSION = '0.1.0'

    @keyword("Extract All Links")
    def get_all_links(self, txt: str) -> list:
        lines = [t.strip() for t in txt.splitlines(keepends=False)]
        return [l for l in lines if l.startswith('http://') or l.startswith('https://')]
